<?php
/**
 * Filename: agents_mod.php
 * Description: Add or modify agent.
 *
 * Accessibility:
 * - Adding new agent can only be done by ADMIN or MANAGER
 * - Editing the agent can only be done by ADMIN or MANAGER or AGENT LOGIN
 *
 * Method: Direct
 * Output: Direct
 */
include 'start.php';
global $settings, $login_user;

// redirect invalid access to dashboard.
if (!login_level_check(USER_LOGIN_MANAGER)) {
    // verify that current profile is agent or not.
    $current_profile = new agent;
    $current_profile->initialize($_GET['idr']);
    $current_profile_agent = $current_profile->billable == 1; // billable = 1 means agent.

    $allowed_agents = $login_user->getAgents();
    if ($current_profile_agent && !in_array($current_profile->id, $allowed_agents)) {
        // currently modifying agent's id is not part of login user's allowed agents - so reject access!
        header('Location:'.$settings['sitepath'].'admin/');
        exit();
    }
}

$destinationfolder = 'agents';
$destinationtable = $destinationfolder;

if ($_POST):
	$current_mode   = $_POST['mode'];           // either `new` or `modify`.
    $idr            = $_POST['idr'] ?: false;   // could be empty if `new`.
    $allow_submit   = true;                     // verify $_POST data and if not good, turn this variable to false and print error.

    $_POST['modify_date'] = $now;   // modify date is always "now".
    $_POST['description'] = $_POST['metadescription'];      // SEO stuff

    // if new, set create_date & order
    if ($current_mode == 'new') {
        $_POST['create_date'] = $now;
        $_POST['ord'] = getendfield($destinationtable,'ord','MAX') + 1;
    }

    // ATTEMPT TO FIND AGENT CLASS ( BILLABLE OR NOT )
    $selected_agent_class = false;   // either billable or not billable. Set to false as default.
    if ($_POST['class'] != '') {
        foreach ($settings['agent_classes'] as $agent_class) {
            if ($agent_class['id'] == $_POST['class']) {
                $selected_agent_class = $agent_class; // line up current agent class to this object.
            }
        }
    }

    // if agent class is set, process logics based on whether its billable or non-billable
    if ( $selected_agent_class && !$selected_agent_class['billable']) {
        // attempting to add a non-licensed, non-billable spot - fine.
        $_POST['agentid'] = ''; // kill agent ID, not allowed to have this.

        // do not allow these words as "Position" for unlicensed member.
        $agent_pattern = "/(agent|real|broker|estate|property)/i";
        if (preg_match($agent_pattern, $_POST['position']) == 1) {
            $_POST['position'] = 'Unlicensed Assistant';
        }
    }

    // ON SUBMIT BEHAVIOR
    if ($allow_submit) {
        // submit to form - process custom fields, initialize agent data
        $update_id = form_to_table($destinationtable, $_POST, $idr);

        if (is_numeric($update_id)) {
            $agent = new agent;
            $agent->initialize($update_id);

            process_custom_fields($agent);

            // different success messages depending on "created" or "modified"
            $post_title         = $agent->displayname;
            $page_id_display    = login_level_check(USER_LOGIN_BRIXWORK) ? '(ID: '.$update_id.')' : '';
            $status             = ($current_mode == 'new' && $idr === false) ? 'added' : 'modified';
            $_SESSION['success-message'] = "<p><b>Success!</b> The agent data has been $status for <span style='text-decoration: underline'>$post_title $page_id_display</span>.</p>";

            // redirect & refresh the object data.
            header('Location:'.$settings['sitepath'].ltrim($_SERVER['PHP_SELF'], '/').'?idr='.$update_id);
            exit();
        } else {
            $error = "<p><b>Error!</b> Please contact Brixwork Support with this ID: <span style='text-decoration: underline'>$update_id</span></p>";
        }
    } else {
        $error = "<p><b>Warning!</b> Invalid value passed. Please verify your input or contact Brixwork Support.</p>";
    }
endif; // if($_POST['submitform']):


// TODO: Add ?version='.$brixwork_version to js. AND minify!
// these scripts are only need when form is being edited ... do not include when the form is being submitted
$scriptinclude = array('brixwork_images.source.js', 'agents_mod.source.js', 'aws-sdk-2.40.0.min.js', 'brixwork_attach.source.js');

include 'header.php';

$preset_object_type = "agents";                             // essential variable ... must be after header.php
include "includes/object_mod_tabs/object_mod__prep.php";    // essential file inclusion


/** @var $agent agent    agent is initialized in the object_mod__prep.php */
// different behavior depending on existence of agent classes setting.
$billable_table_exists = (bool)$settings['agent_classes'];
if ( $billable_table_exists ):
    // two separate counters for billable & non-billable members
    $agent_count        = list_agents(array('billable' => 1), 'ord', 'ASC', 500, 1, true);
    $non_agent_count    = list_agents(array('billable' => 0), 'ord', 'ASC', 500, 1, true);
    $show_non_billable  = true;
else:
    // just count all members.
    $agent_count        = list_agents('', 'ord', 'ASC', 500, 1, true);
endif;

$agents_limit = $settings['agents_limit'];
$agents_seats_full = $agent_count >= $agents_limit;

include 'includes/header_html.php';

// Form is disabled under a condition
$disable_form = !$billable_table_exists && $agents_seats_full; // disable form condition
if ($disable_form): // form disabled because members cannot be added anymore
?>
    <div id="disable_member_addition" class="brixwork_admin_container mt-5">
        <h1 id="admin_page__title">Cannot add more members!</h1>
        <div id="agents_overview" class="col-12 my-5">
            <div class="row">
                <div class="col-sm-6 col-md-12 col-lg-6 mb-3 mb-sm-0 mb-md-3 mb-lg-0">
                    <div class="billable_wrapper">
                        <h3>Agent Seats: <?=$agent_count?> / <?=$agents_limit?></h3>
                        <h6 class="seat_available"><?=$agents_limit - $agent_count?> Available</h6>
                    </div>
                </div>
            </div>
        </div>
        <div class="content_wrapper my-5">
            <h5 class="pt-5">Contact <a href="mailto:info@brixwork.com">info@brixwork.com</a> to increase number of seats!</h5>
        </div>
        <div class="return_button_wrapper">
            <a href="agents.php" type="button" class="btn btn-admin add_spacing">Return</a>
        </div>
    </div>

<?php
else: // enable form ?>
    <form method="post" role="form" id="agents_mod_form" class="brixwork_admin_container mod_form" enctype="multipart/form-data" action="<?=$_SERVER['PHP_SELF']?>">
        <h1 id="admin_mod__title">
            <?php if($_GET['mode']=='new') { echo 'Adding A New Member'; } else { echo 'Editing '.$agent->displayname; } ?>
        </h1>

        <?php
        session_alert_display('success-message');

        if ($error)
            echo brixwork_alert($error, 'error');

        // BOOTSTRAP 5 TABS - Command + F to find HTML content for each tab
        $nav_tab_array = is_object($agent) ? array('Basic Info', 'Contact Info', 'Photos', 'Videos', 'SEO') : array('Basic Info', 'Contact Info', 'SEO');
        brixwork_object_tabs('agent', $nav_tab_array)
        ?>

        <?php // ALL CORRESPONDING TAB CONTENTS ?>
        <div class="manage_object_tab_content tab-content">
            <?php // BASIC INFO CONTENT ?>
            <div class="manage_agent_each_tab tab-pane fade show active" id="basic-info-tab" role="tabpanel" aria-labelledby="Basic-Info" tabindex="0">
                <?php include "includes/object_mod_tabs/agents_mod__basic_info.php";?>
            </div>

            <?php // DETAILS TAB CONTENT ?>
            <div class="manage_agent_each_tab tab-pane fade" id="contact-info-tab" role="tabpanel" aria-labelledby="Contact-Info" tabindex="0">
                <?php include "includes/object_mod_tabs/agents_mod__contact.php";?>
            </div>

            <?php // PHOTOS TAB CONTENT ... only added if $agent is available.
            if (is_object($agent)) { ?>
                <div class="manage_agent_each_tab tab-pane fade" id="photos-tab" role="tabpanel" aria-labelledby="Photos" tabindex="0">
                    <?php include "includes/object_mod_tabs/object_mod__photos.php"; ?>
                </div>

                <?php // ATTACHMENTS TAB CONTENT ?>
                <div class="manage_agent_each_tab tab-pane fade" id="videos-tab" role="tabpanel" aria-labelledby="Videos" tabindex="0">
                    <?php include "includes/object_mod_tabs/object_mod__attach.php"; ?>
                </div>
            <?php
            } ?>

            <?php // SEO TAB CONTENT ?>
            <div class="manage_agent_each_tab tab-pane fade" id="seo-tab" role="tabpanel" aria-labelledby="SEO" tabindex="0">
                <?php include "includes/object_mod_tabs/object_mod__seo.php"; ?>
            </div>
        </div>

        <div id="submit_button_group">
            <?php // HIDDEN INPUT TO BE USED IN $_POST[]
            if (is_object($agent)) {
                $idr_val = $agent->id;
                $mode_val = 'modify';
            } else {
                $idr_val = false;
                $mode_val = 'new';
            }
            if ($idr_val) {
                echo "<input type='hidden' name='idr' id='idr' value='$idr_val' />";
            }
            echo "<input type='hidden' name='mode' value='$mode_val' />";
            ?>

            <input type="submit" name="submitform" id="pagesubmit" class="btn btn-admin" value="<?=$mode_val == 'new' ? 'Add Agent' : 'Save Agent'?>" />
            <a class="btn btn-admin light_blue" href="agents.php">Back</a>
        </div>
    </form>

<?php
endif; // if ($disable_form)

include 'footer.php';