<?php
/**
Filename: ajax_listbuildinglist.php

Method: AJAX (from homes_mod.php and buildings.php) 
Output: JSON

Description: Returns a list of buildings that match the number, street & city search set. 
used in the Homes mod screen to find buildings that match the entry, OR for the buildings list screen for adding (featuring) new buildings. 

Author: Jeff Kee
*/

include 'start.php';

// start.php runs validate_login() function.
$destinationfolder = 'buildings';
$destinationtable = 'buildings';


// min required variables!
if ( ($_REQUEST['street']!='' && $_REQUEST['number']!='' && $_REQUEST['city']) || $_REQUEST['name']!='' || $_REQUEST['mainid']!='' ):

	// Check each condition from smallest to largest scale and build QUERY accordingly.
	if ( $_REQUEST['name']!='' ) {
		$query['name'] = $_REQUEST['name'];
	}
	else if( $_REQUEST['mainid'] ) {
		$query['id'] = $_REQUEST['mainid'];
		$getsubbuildings = true;
	}
	else {
		$street_array = separate_streetname(trim($_REQUEST['street'])); // returns array($streetname, $streettype, $street_dir, $street_suffix);
		$query['street']	= $street_array[0];
		$query['number']	= $_REQUEST['number'];
		$query['city']		= $_REQUEST['city'];

		if($_REQUEST['street_dir']) {
			$query['street_dir'] = $_REQUEST['street_dir'];
		}
	}

	$barray = get_buildings($query, array('name', 'street', 'number'), array('ASC', 'ASC', 'ASC'), 10, 1, false, true);

	// we need sub-buildings so run from previous $barray for NEW array!
	if($getsubbuildings==true) {
		// just got a mainid, so means return the SUB buildings as array!
		$mainbuilding = new building;
		//$mainbuilding->initialize($barray[$query['id']]['id'], $barray[$query['id']]); // only one result for top building, presumably.
        $mainbuilding->initialize($_REQUEST['mainid']); // main building is the building with the main_id.
        $barray = $mainbuilding->load_subbuildings();   // Override the building array to be sub-buildings of the main building.
	}

	if(!$barray) {
		$count = 0;
		$buildings = '';
        $message = "Building array does not exists";
	}
	else {
		$count	= count($barray);
		$bcount	= 0;
        $message = "Counting in progress";

		foreach($barray as $bkey => $bid) {
			$thisbuilding = new building;
			if (is_array($bid)) {
				// if data is fed.
				$thisbuilding->initialize($bkey, $bid);
			} else {
				// only ID
				$thisbuilding->initialize($bid);
			}

			$thisbuilding->load_subbuildings();
			$buildings[$bcount] = array(
				'value' => $thisbuilding->id,
				'id' => $thisbuilding->id,
				'selected' => $_REQUEST['buildingid']==$thisbuilding->id,
				'display' => (!$thisbuilding->defaultname ? $thisbuilding->name.' ('.$thisbuilding->address.')' : $thisbuilding->name),
				'city'=> $thisbuilding->city,
				'area'=> $thisbuilding->area,
				'feature'=>$thisbuilding->feature,
				'mainid'=>$thisbuilding->mainid,
				'subids'=>$thisbuilding->subids
			);
			$bcount++;
		}
	}
else:
	$count = 0;
	$buildings = '';
    $message = 'Not enough data passed';
endif;

$json_array = array('count' => $count, 'buildings' => $buildings, 'message' => $message);
echo json_encode($json_array);

require_once 'ajax_footer.php';