<?php
/**
Filename: ajax_listbuildinglist.php

Method: AJAX (from homes_mod.php and buildings.php) 
Output: HTML

Description: Returns a list of buildings that match the number, street & city search set. 
used in the Homes mod screen to find buildings that match the entry, OR for the buildings list screen for adding (featuring) new buildings. 

Author: Jeff Kee
*/
include 'start.php';

// start.php runs validate_login() function
global $settings, $login_user;

$destinationfolder = 'buildings';
$destinationtable = 'buildings';

$query['feature'] = 1;

if( isset($_REQUEST['filters']) && is_array($_REQUEST['filters']) && count($_REQUEST['filters'])>0) {
    $filters = param_to_query($_REQUEST['filters']);
    $query = array_merge($query, $filters);
} else {
    $filters = false;
}

/**
 * Query the database for agent id.
 * This will disable the re-ordering for each agent.
 * Re-ordering on filtered query is very complicated :/ How to re-order without affecting the master list?
 */
if (!login_level_check(USER_LOGIN_MANAGER)) {
    $query['agent'] = $login_user->getAgents() ?: -1;
}

// Query settings.
$orderby    = array('ord', 'create_date');
$ascordesc  = array('ASC', 'DESC');
$perpage    = $_REQUEST['perpage'] ?? 10000;
$page       = $_REQUEST['page'] ?? 1;

$buildings 		= get_buildings($query, $orderby, $ascordesc, $perpage, $page);
$buildingscount = get_buildings($query, $orderby, $ascordesc, 100000, $page, true);

if (!$buildings) :
    // no buildings queried - print appropriate errors
    ?>
    <div class="row justify-content-center">
        <div class="col-lg-4 col-sm-6 col-xs-12" style="padding-top: 50px">
            <?php
            if ($login_user->getLevel() == USER_LOGIN_AGENT && !$login_user->getAgents()) {
                // no agent attached to user error
                echo alert_display('<p><strong>No Agent Attached to User</strong><br />Currently logged-in user does not have agent profile attached, which may prevent all listings/buildings to show. Please contact site admin for support.</p>');
            } else {
                // no buildings queried error
                echo alert_display('<p><strong>No featured buildings!</strong><br />You need to set up some buildings to feature on your site. Note that not all websites are equipped with the building feature.</p>', 'warning');
            }

            if ($settings['mls_integrated'] == 1) {
                // MLS activated means building data exists through Brixwork group buildings function.
                echo '<p class="pt-2">Many buildings may already be in your database as per the MLS&reg; feed. Please use the search tool above to find out.</p>';
            }
            ?>
        </div>
    </div>

<?php
else:
    // BUILDINGS - display them.
    $numpages = ceil($buildingscount / $perpage);
    if ($numpages > 1) // no need for pagination if just one page.
        echo brixwork_object_pagination('building', $page, $numpages);

    ?>
    <div id="buildingstable">
        <?php // LOOP THROUGH BUILDINGS ARRAY ... basically follow the same format as "list homes"
        foreach ($buildings as $building_id) :
            $each_building = new building();
            $each_building->initialize($building_id);

            /**
             * Depending on Login user, some listings will not be visible
             * 1. Admin/Manager can see all listings.
             * 2. Agents and lower can only see listings they are associated with.
             */
            $agent_visibility = true;
            $building_class = $agent_visibility ? '' : 'd-none';
            $not_active_keys = array(1, 2); // "Coming Soon", "VIP Preview" are "not active" status.

            // start building tags
            $added_tags  = $each_building->feature == 1 ?	' home_feature' : '';   // toggle
            $added_tags .= $each_building->publish == 1 ?	' home_publish' : '';   // hidden or publish ( 2nd dropdown )
            $added_tags .= in_array($each_building->statusid, $not_active_keys) ?	' home_sold' : '';      // label green or red ( active vs. coming soon )

            $building_area_city = $each_building->area ? $each_building->area.', '.$each_building->city : $each_building->city;

            // duplicate buildings ... echo hidden input for later use.
            $duplicate_bldg_array = $each_building->get_duplicate_buildings();
            $duplicate_bldg_resolve = count($duplicate_bldg_array) > 0;
            if ($duplicate_bldg_array) {
                foreach ($duplicate_bldg_array as $duplicate_id) {
                    unset($each_duplicate_bldg);
                    $each_duplicate_bldg = new building;
                    $each_duplicate_bldg->initialize($duplicate_id);
                    $each_duplicate_bldg->get_listings();
                    $each_duplicate_bldg_name = $each_duplicate_bldg->name ?: '';
                    $each_duplicate_bldg_desc = limit_string_at_space(strip_tags($each_duplicate_bldg->desc), 50, '&hellip;');
                    $each_duplicate_bldg_img  = $each_duplicate_bldg->get_main_images_path(0, $settings['sitepath'].'admin/images/noimage.jpg');

                    echo "<input type='hidden' class='dupbuilding_$each_building->id' name='dupbuilding[$each_building->id]' rel='$each_building->id' value='$duplicate_id' 
                        data-address='$each_duplicate_bldg->address' 
                        data-numlistings='$each_duplicate_bldg->numlistings' 
                        data-name='$each_duplicate_bldg_name'
                        data-description='$each_duplicate_bldg_desc'
                        data-mainimage='$each_duplicate_bldg_img'
                        />";
                }
            }

            $sub_bldg_count = is_array($each_building->subids) ? count($each_building->subids) : 0;
            $each_building_img_class = login_level_check(USER_LOGIN_MANAGER) ? array('img-full', 'orderhandle') : array('img-full');    // disable re-order for agents & content manager
            ?>

            <div class="each_admin_listing <?=$building_class?> <?=$added_tags?> row source_0" id="building_<?=$each_building->id?>">
                <div class="admin_listing__img_wrapper">
                    <?=$each_building->get_main_images(0, 275, 200, $settings['sitepath'].'admin/images/noimage.jpg', $each_building_img_class)?>
                </div>

                <div class="admin_listing__summary">
                    <h4 class="full_address">
                        <?=$each_building->name?>
                    </h4>

                    <h5 class="building_address"><?=$each_building->address?><br><?=$building_area_city?></h5>

                    <div class="duplicate_sub_bldg">
                        <?php if ($duplicate_bldg_resolve): ?>
                            <button class="btn btn-admin reddish dupbuilding_resolve" rel="<?=$each_building->id?>"><?=count($duplicate_bldg_array)?> duplicates</button>
                        <?php endif;?>

                        <?php if ($sub_bldg_count > 0):?>
                            <div class="btn btn-admin marine no_hover"><?=$sub_bldg_count?> sub-buildings</div>
                        <?php endif; ?>
                    </div>
                </div>


                <div class="admin_listing__functions">
                    <?php
                    // This button group is only available for valid users
                    $level_exclusive = $login_user->getLevel() == USER_LOGIN_CONTENT_MANAGER; // some functions are disabled just for the content manager
                    $disable_function = $level_exclusive ? 'disabled' : '';
                    if ($agent_visibility) { ?>
                        <div class="functions_wrapper d-flex flex-wrap pb-2">
                            <label for="visibility_toggle" class="orange px-1 w-100 mx-auto my-0">Status</label>
                            <div class="status_wrapper p-1">
                                <select id="status_toggle" class="form-select building_status_toggle" rel="<?=$each_building->id?>" aria-label="Change status of the listing" <?=$disable_function?>>
                                    <?php
                                    if (isset($settings['building_status_display']) && is_array($settings['building_status_display'])):
                                        foreach ($settings['building_status_display'] as $key => $each_building_status):
                                            $selected       = $each_building->statusid == $key;
                                            $selected_attr  = $selected ? 'selected' : '';
                                            if ($level_exclusive && !$selected) continue;   // do not display the options for invalid logins.
                                            ?>
                                            <option value="<?=$key?>" <?=$selected_attr?>><?=$each_building_status?></option>
                                        <?php
                                        endforeach;
                                    endif; ?>
                                </select>
                            </div>

                            <div class="status_wrapper mt-auto p-1">
                                <select id="visibility_toggle" class="form-select building_publish_toggle" rel="<?=$each_building->id?>" aria-label="Hide or Publish Listing to the public" <?=$disable_function?>>
                                    <?php // prep data
                                    $publish_status_array = array(
                                        0 => 'Hidden',
                                        1 => 'Published'
                                    );
                                    // loop through
                                    foreach ($publish_status_array as $value => $text) {
                                        $selected       = $each_building->publish == $value;
                                        $selected_attr  = $selected ? 'selected' : '';
                                        if ($level_exclusive && !$selected) continue;

                                        echo "<option value='$value' $selected_attr>$text</option>";
                                    } ?>
                                </select>
                            </div>


                            <div class="p-1 d-flex">
                                <div class="form-check" id="brixwork_radio_check">
                                    <input class="form-check-input brixwork_radio <?=$level_exclusive ? '' : 'bldg_remove_check'?>" type="radio" name="building_feature_<?=$each_building->id?>" id="<?=$each_building->id?>" <?=$disable_function?> checked>
                                    <label class="form-check-label" for="<?=$each_building->id?>">Featured</label>
                                </div>
                            </div>
                        </div>
                    <?php
                    } ?>

                    <?php // BUILDINGS QUICK STATS ?>
                    <div class="quick_stats_wrapper row px-1 py-2">
                        <?php
                        $quick_stats_array = array('short_term_rental', 'rental', 'pets'); // stats to show
                        $quick_stats_str = array('Short-Term Rentals', 'Long-Term Rentals', 'Pets Allowed'); // corresponding string
                        foreach ($quick_stats_array as $key => $quick_stat) {
                            if ($each_building->$quick_stat) { ?>
                                <div class="quick_stat col-sm-4"><?=$quick_stats_str[$key]?></div>
                                <?php
                            }
                        } ?>
                    </div>


                    <?php // BUILDINGS FUNCTION WRAPPER This button group is only available for legit user
                    if ($agent_visibility) { ?>
                        <div class="buttons_wrapper px-1">

                            <a href="buildings_mod.php?idr=<?=$each_building->id?>&mode=modify">
                                <button class="btn btn-admin light_blue px-4" type="button">
                                    Edit
                                </button>
                            </a>
                            <a href="<?=$each_building->get_building_link($settings['url_trail'])?>">
                                <button class="btn btn-admin grey_teal px-4" type="button">
                                    View
                                </button>
                            </a>
                            <a href="<?=generateQrCode($each_building->get_building_link($settings['url-trail']), 450)?>" class="brixwork_qr" target="_blank" data-bs-toggle="tooltip" data-bs-placement="bottom" title="Generate a direct QR code">
                                <i class="bi bi-qr-code"></i>
                            </a>
                        </div>
                    <?php
                    } ?>
                </div>
            </div>

        <?php
        endforeach; ?>
    </div>
    <?php
    if ($numpages > 1) // no need for pagination if just one page.
        echo brixwork_object_pagination('building', $page, $numpages);

endif; // if (!buildings):

require_once 'ajax_footer.php';