<?php
/*
Filename: ajax_listhomes.php

Method: AJAX
Output: AJAX HTML

Description: Generates the homes list with wide icons that display each home, edit/photo attachment screens etc. This is called in by the homes.php screen, fully HTML'd results. Not suitable for other purposes such as the MLS search. 

Author: Jeff Kee
*/
include 'start.php';

// start.php runs validate_login() function
global $settings;
global $login_user;

$destinationfolder = 'homes';
$destinationtable = 'homes';

$query['ownlisting'] = 1; // source=0 or feature=1 listings!

if( isset($_REQUEST['filters']) && is_array($_REQUEST['filters']) && count($_REQUEST['filters'])>0) {
    $filters = param_to_query($_REQUEST['filters']);
    $query = array_merge($query, $filters);
} else {
    $filters = false;
}

/**
 * Query the database for agent id.
 * This will disable the re-ordering for each agent.
 * Re-ordering on filtered query is very complicated :/ How to re-order without affecting the master list?
 */
if (!login_level_check(USER_LOGIN_MANAGER)) {
    $query['agent'] = $login_user->getAgents() ?: -1; // Agents and content managers only has access to listings they are specifically assigned to.
}

// Query settings.
$orderby    = array('ord', 'create_date');
$ascordesc  = array('ASC', 'DESC');
$perpage    = $_REQUEST['perpage'] ?? 10000;
$page       = $_REQUEST['page'] ?? 1;

$homes      = get_properties('', $query, $orderby, $ascordesc, $perpage, $page);
$homescount = get_properties('', $query, $orderby, $ascordesc, 100000, $page, true);

if (!$homes):
    // no homes queried - display appropriate errors.
    ?>
    <div class="row justify-content-center">
        <div class="col-lg-4 col-sm-6 col-xs-12" style="padding-top: 50px">
            <?php
            if ($login_user->getLevel() == USER_LOGIN_AGENT && !$login_user->getAgents()) {
                // no agent attached to user error
                echo alert_display('<p><strong>No Agent Attached to User</strong><br />Currently logged-in user does not have agent profile attached, which may prevent all listings/buildings to show. Please contact site admin for support.</p>');
            } else {
                // no homes queried error
                echo alert_display('<p><strong>No listings yet!</strong><br/> Seems like you don\'t have your own listings yet. OR you don\'t have access. Contact site admin or Use the Add New Listing function above or wait for MLS® sync to start.</p>', 'warning');
            }
            ?>
        </div>
    </div>

<?php
else:
    $numpages = ceil($homescount / $perpage);
    if ($numpages > 1) // no need for pagination if just one page.
        echo brixwork_object_pagination('home', $page, $numpages);

    // start listing homes.
    echo "<div id='homestable'>";

    foreach($homes as $home_id):
        $analytics = gAnalytics($home_id,true);
        $each_home = new home;
        $each_home->initialize($home_id);

        $agent_visibility = true;

        // useful variable
        $has_building = !empty($each_home->building); // not empty variable

        // start building tags
        $added_tags  = $each_home->feature == 1 ?	' home_feature' : '';
        $added_tags .= $each_home->publish == 1 ?	' home_publish' : '';
        $added_tags .= $each_home->sold != 0 ?		' home_sold' : '';

        $display_condition = $agent_visibility;
        $each_home_img_class = login_level_check(USER_LOGIN_MANAGER) ? array('img-full', 'orderhandle') : array('img-full');
        ?>

        <div class="each_admin_listing <?=$display_condition ? '' : 'd-none'?> <?=$added_tags?> source_<?=$each_home->source?> row" id="home_<?=$each_home->id?>">
            <div class="admin_listing__img_wrapper">
                <?=$each_home->get_main_images(0, 275, 200, $settings['sitepath'].'admin/images/noimage.jpg', $each_home_img_class)?>
            </div>

            <div class="admin_listing__summary">
                <h6 class="mls_num"><?=$each_home->mls ? 'MLS# '.$each_home->mls : 'NO MLS® NUMBER' ?></h6>

                <h4 class="full_address"><?=$each_home->address?><br/><?=$each_home->areacity?></h4>

                <p class="type"><?=$each_home->type?></p>
                <p class="edit_building" style="display: <?=$has_building ? 'block' : 'none'?>;">
                    in <a href="buildings_mod.php?idr=<?=$each_home->bldg->id?>&mode=modify"><?=$each_home->building?></a>
                </p>
                <h6 class="price"><?=$each_home->price?></h6>
            </div>

            <div class="admin_listing__functions">
                <div class="functions_wrapper">
                    <?php
                    if ($display_condition): // only show this section if OWN listing ?>
                        <label for="visibility_toggle" class="orange w-100 mx-auto my-0">Status</label>

                        <div class="status_wrapper mt-auto">
                            <select id="visibility_toggle" class="form-select home_publish_toggle" rel="<?=$each_home->id?>" aria-label="Hide or Publish Listing to the public">
                                <option value="0" <?=$each_home->publish == 0 ? 'selected' : ''?>>Hidden</option>
                                <option value="1" <?=$each_home->publish == 1 ? 'selected' : ''?>>Published</option>
                            </select>
                        </div>
                        <div class="status_wrapper mt-auto" style="padding-right: 1rem">
                            <select id="status_toggle" class="form-select home_sold_toggle" rel="<?=$each_home->id?>" aria-label="Change status of the listing">
                                <option value="0" <?=$each_home->sold == 0 ? 'selected' : ''?>>Active</option>
                                <option value="1" <?=$each_home->sold == 1 ? 'selected' : ''?>>Sold</option>
                                <option value="2" <?=$each_home->sold == 2 ? 'selected' : ''?>>Show On Both</option>
                            </select>
                        </div>
                    <?php
                    endif; ?>

                    <div class="status_wrapper form-check form-switch my-auto" data-bs-toggle="tooltip" data-bs-title="Show this listing on the Homepage and/or the Featured Listings Page, depending on configuration.">
                        <input class="form-check-input home_feature_toggle" rel="<?=$each_home->id?>" value="<?=$each_home->feature?>" type="checkbox" role="switch" id="home_feature_switch" <?=$each_home->feature ? 'checked' : ''?>>
                        <label class="form-check-label orange m-0" for="home_feature_switch" id="home_feature_toggle_label">Featured</label>
                    </div>

                </div>


                <?php
                if ($each_home->source == 1) { // only show this section if MLS listing
                    echo "<div>";
                    echo '<h5 class="mls_display" data-bs-toggle="tooltip" data-bs-placement="bottom" data-bs-title="Un-featuring MLS® Listing will simply hide it from your website">RECIPROCITY LISTING</h5>';
                    echo "</div>";
                }?>


                <div class="buttons_wrapper">
                    <?php // only display if OWN listing
                    if ($each_home->source == 0) {
                        echo '<a class="btn btn-admin light_blue px-4" href="homes_mod.php?idr='.$each_home->id.'&mode=modify">Edit</a>';
                    } ?>

                    <a class="btn btn-admin grey_teal px-4" href="<?=$each_home->get_property_link($settings['url_trail'])?>">Preview</a>

                    <?php // only display if OWN listing
                    if ($each_home->source == 0) {
                        echo '<a class="btn btn-admin reddish home_delete px-4" rel="'.$each_home->id.'">Delete</a>';
                    } ?>

                    <a href="<?=generateQrCode($each_home->get_property_link($settings['url-trail']), 450)?>" class="brixwork_qr" target="_blank" data-bs-toggle="tooltip" data-bs-placement="bottom" title="Generate a direct QR code">
                        <i class="bi bi-qr-code"></i>
                    </a>
                </div>
            </div>
        </div>

    <?php
    endforeach; // closing div for "homestable"

    if ($numpages > 1) // no need for pagination if just one page.
        echo brixwork_object_pagination('home', $page, $numpages);
endif;

require_once 'ajax_footer.php';