<?php
/*
Filename: ajax_listhomeslist.php

Method: AJAX
Output: AJAX HTML

Description: Gets JSON result of listings for quick display purposes. Important to distinguish from ajax_listhomes.php which displays all the listings under the Listings tab.
This ajax_listhomeslist.php file generates MLS search results etc. on the Dashboard. 

Author: Jeff Kee
*/
include 'start.php';
global $local, $settings;

// start.php runs validate_login() function.
$perpage = 100; // back-end search, always limit to just 10 per page results.

if($_REQUEST['listing_order_by']!='') {
	$orderby = $_REQUEST['listing_order_by'];
} else {
	$orderby = array(
		'create_date',
		'ord'
	);
}

if($_REQUEST['listing_order_direction']!='') {
	$orderdirection = $_REQUEST['listing_order_direction'];
} else {
	$orderdirection = array(
		'DESC',
		'ASC'
	);
}


$page = ($_REQUEST['page']!='' ? $_REQUEST['page'] : 1);
$initialquery = param_to_query($_REQUEST); // turn all inbound requests.
if($initialquery!==false) {
	$query = remove_empty_vars($initialquery);
} else {
	$query = array();
}
if($query['typeid']==0) unset($query['typeid']);

$query['publish'] = 1;

// if MLS # is set, we cut everything else out!
if($query['mls']!='') {
	$mls = $query['mls']; // save variable.
	$query = array();
	$query['mls'] = $mls;
	// no longer need publish. just have it pop up anyway.
}

$masteridresult = $mysqli->query("SHOW COLUMNS FROM `homes` LIKE 'masterid'");
$query['skipmasterid'] = !$masteridresult->num_rows;

if((!isset($query['mls']) || $query['mls']=='') && (!isset($query['cityid']) || $query['cityid']=='')) {
	// invalid query.
	// at least we need an MLS #, or a city selected.
    $count = $homescount = 0;
}
else {
	// good query, so let's run results.
    // var_dump('im in the else statement now ... good query?');
	$homes = get_properties('', $query, $orderby,$orderdirection, $perpage,$page, false, true);
	$homescount = get_properties('',$query,$orderby,$orderdirection,$perpage,$page, true);

	// override IF mls # is entered, and nothing found... look for it in server. 
	if($query['mls']!='' && $homes==false) {
		// straight up MLS # search from mothership sites, not local!
		if($settings['mls_import_url']!='') {
			// if separate MLS import url is set such as kamloops or other region... 
			$importurl = $settings['mls_import_url'];
		} else {
			// otherwise default to demo.brixwork.com which is master_url, for MLS from REBGV MLS feed. 
			$importurl = 'https://vancouver.brixwork.com/';
		}


		include '../cron/cron_functions.php';// open functions that run the remote fetch. 
		include '../admin/includes/retsimport_vars.php';// loads up all cities etc. 
		retsrunning_close(); // must run when loading cron_functions.php to load up cities. 
		$getarray['hash'] = md5('58300774'.$_REQUEST['mls']);
		$getarray['mls'] = $_REQUEST['mls'];
		$getarray['rand'] =  rand(0,9999);
		$jsonfeed = curl_get_file_contents($importurl.'admin/api/listing.php?hash='.$getarray['hash'].'&mls='.$getarray['mls'].'&rand='.$getarray['rand'], 'GET');
		$json = json_decode($jsonfeed, true); // fetch from the listing API from main server.

		if($json['code']==1) {
			$listing = $json['listing'][0];

			$remotehome = new home;
			$listing['id'] = $listing['masterid'];
			$remotehome->initialize($listing['id'], $listing); // initialize from provided data? 
			$homedata = get_object_vars($remotehome);

			$homedata_append = array(
				'datasource'=>'remote',
				'value' => $listing['masterid'],
				'source' => 1,
				'image'=> ($listing['mls_photo']!='' ? $listing['mls_photo'] : $settings['sitepath'].'admin/images/noimage.jpg'),
				'url' => '',
				'city'=> $listing['cityname'],
				'area'=> $listing['areaname'],
				'areacity'=>($listing['areaname']!='' ? $listing['areaname'].', ' : '').$listing['cityname'],
				'type'=>$listing['typename'],
				'dom'=>floor(($local - strtotime($listing['create_date']))/(60*60*24)),
			);

			$homearray[0] = array_merge($homedata, $homedata_append);


			$message = 'Fetched remotely through '.$importurl.'admin/api/listing.php?hash='.$getarray['hash'].'&mls='.$getarray['mls'];
			$count = 1;
		} else {
			$homes = false;
			$count = 0;
			$message = 'No results found.';
		}
	} else {
		// local query only as it was not an MLS # entered. 
		if($homes==false) {
			$count = $homescount = 0; // zero homes result. 
			$message = 'No homes matched the request.';
		} else {
			/* END OF PAGE LINKS FOR NAV */
			$message = $homescount;
			$count = $homescount;
			foreach($homes as $home) {
				$thishome = new home;
				$thishome->initialize($home['id'], $home);
				$homearray[] = array(
					'datasource'=>'local',
					'value' => $thishome->id,
					'source' => $thishome->source,
					'id' => $thishome->id,
					'mls' => $thishome->mls,
					'image'=> $thishome->get_main_image_path($settings['sitepath'].'admin/images/noimage.jpg'),
					'url'=>$thishome->get_property_link($settings['url_trail'],($settings['']!='' ? : 'showlisting/')),
					'fulladdress' => $thishome->fulladdress,
					'address' => $thishome->address,
					'city'=> $thishome->city,
					'area'=> $thishome->area,
					'areacity'=>$thishome->areacity,
					'bedroom'=>$thishome->bedroom,
					'bathroom'=>$thishome->bathroom,
					'sqft'=>$thishome->sqft,
					'lot'=>$thishome->lot,
					'year'=>$thishome->year,
					'feature'=>$thishome->feature,
					'type'=>$thishome->type,
					'dom'=>floor(($local - strtotime($thishome->data['create_date']))/(60*60*24)),
					'price'=>$thishome->price,
					'maintenance'=>$thishome->maintenance,
					'providedby' => ($thishome->providedby != '' ? $thishome->providedby : '')
				);
				$hcount++;
			}
		}
	}
}

$json_array = array('count'=>$count, 'homes'=>$homearray, 'message'=>$message);
echo json_encode($json_array);

require_once 'ajax_footer.php';