<?php
/*
Filename: buildings.php

Method: Direct
Output: Direct

Description: Master file that loads up the buildings list, as well as the buildings quick search module to help users organize & choose buildings to feature on the website. 

Author: Jeff Kee
*/
include 'start.php';
global $settings, $login_user;

// TODO: REVERT BACK TO BUILDINGS.JS
$scriptinclude = 'buildings.source.js';

$destinationfolder = 'buildings';
$destinationtable = 'buildings';

include 'header.php';
// header_html is separated from header.php on purpose.
include 'includes/header_html.php';

$svg_append = 'images/admin_function_icon/';
$plus_sign_svg = get_svg(file_get_contents($svg_append.'plus_sign.svg', true))
?>
<div id="listings_gallery_intro" class="brixwork_admin_container title">
    <h1 id="admin_page__title">Featured Buildings</h1>

    <div id="listings_filter_row" class="row">
        <h5 class="filter_title">Filter</h5>

        <div id="listings_filter__status" class="col-md-3 py-1 py-lg-0">
            <select class="form-select buildings_filter" name="status" id="buildings_filter_status" aria-label="buildings_filter">
                <option value="">All</option>
                <?php
                if (isset($settings['building_status_display']) && is_array($settings['building_status_display'])):
                    foreach ($settings['building_status_display'] as $key => $each_building_status):
                        $selected = (isset($_COOKIE['buildings_filter_status']) && $_COOKIE['buildings_filter_status'] == $key) ? 'selected' : '';
                        ?>

                        <option value="<?=$each_building_status?>" <?=$selected?>><?=$each_building_status?></option>

                    <?php
                    endforeach;
                endif;
                ?>
            </select>
        </div>

        <div id="listings_filter__name" class="col-md-4 py-1 py-lg-0">
            <input type="text" class="form-control buildings_filter" id="buildings_filter_name" name="name" placeholder="i.e. Pier West" size="20" aria-label="Filter by Name"/>
        </div>

        <div id="listings_filter__street" class="col-md-4 py-1 py-lg-0">
            <input type="text" class="form-control buildings_filter" id="buildings_filter_street" name="street" placeholder="i.e. Marine" size="20" aria-label="Filter by Street Name"/>
        </div>

        <div id="listings_filter__button" class="col-md-1 py-1 py-lg-0">
            <button class="btn btn-admin" id="buildings_filter_trigger">Filter</button>
        </div>
    </div>

    <div id="listings_filter_row" class="row">
        <h5 class="filter_title">Buildings per Page</h5>
        <div id="listings_filter__perpage" class="col-md-4 col-sm-5">
            <select id="perpage" class="form-select" aria-label="Per Page Filter">
                <option value="25">25 per page</option>
                <option value="50">50 per page</option>
                <option value="100">100 per page</option>
                <option value="250">250 per page</option>
            </select>
        </div>

        <div id="listings_filter__legend" class="col-md-8 col-sm-7 pt-4 pt-md-0">
            <div id="each_legend" class="active">
                <p data-bs-toggle="tooltip" data-bs-placement="top" data-bs-title="Listings marked with this color are currently Active">
                    <i class="bi bi-square-fill"></i>&nbsp;&nbsp;Selling Phase
                </p>
            </div>
            <div id="each_legend" class="sold">
                <p data-bs-toggle="tooltip" data-bs-placement="top" data-bs-title="Listings marked with this color are currently Active">
                    <i class="bi bi-square-fill"></i>&nbsp;&nbsp;Coming Soon Phase
                </p>
            </div>
        </div>
    </div>


    <?php // only available for higher access than content manager OR agents that actually have agents attached!
    if ( login_level_check(USER_LOGIN_CONTENT_MANAGER) || ($login_user->getLevel() == USER_LOGIN_AGENT && $login_user->getAgents()) ) { ?>
        <div id="add_object_wrapper" class="pt-4">
            <button id="add_new_object_btn" type="button" class="btn btn-admin light_blue" data-bs-toggle="modal" data-bs-target="#bldg_search_modal">
                <span><?=$plus_sign_svg?></span><span class="title">Add / Search Building</span>
            </button>
        </div>
    <?php
    } ?>
</div>

<div class="brixwork_admin_container" id="buildings_list">
    <?php // AJAX POPULATE WITH BUILDINGS?>
</div>



<?php
// make another primary building module!
//$dupbuilding_resolve = 'dupbuilding_resolve()';
//modal_html('Consolidate Duplicate Buildings', 'Will be generated on the fly anyway, no need to get this', 'dupbuilding_resolve', 'Consolidate to Selected', 'Cancel', $dupbuilding_resolve);
//modal_html('Building Merge Error', 'Will be generated on the fly anyway, no need to get this', 'dupbuilding_error', 'OK', false, false, false);


// DUPLICATE BUILDING MODAL 2023 upgrade
$bldg_duplicate_modal__body = '';
$bldg_duplicate_modal__footer = '
    <button type="button" class="btn btn-admin" data-bs-dismiss="modal">Close</button>
    <button type="button" class="btn btn-admin light_blue px-4" id="bldg_duplicate_resolve" data-bs-dismiss="modal">Consolidate to Selected</button>';
$bldg_duplicate_modal__option = array(
    'header_content' => 'Resolve Duplicate Buildings',
    'body_content' => $bldg_duplicate_modal__body,
    'footer_content' => $bldg_duplicate_modal__footer,
    'id' => 'bldg_duplicates_modal'
);
brixwork_modal_html($bldg_duplicate_modal__option);



$bldg_duplicates_error__option = array(
    'header_content' => 'Building Merge Error',
    'id' => 'bldg_duplicates_error_modal'
);
brixwork_modal_html($bldg_duplicates_error__option);


// UN-FEATURE BUILDING WARNING MODAL
$bldg_remove_modal__body = 'Un-featuring will remove this building from the "Featured Buildings" list. <br> Data will not be deleted, so use "Add New Building" function to feature the building again. <br><br> Or, simply "Hide" the building using "Published" dropdown.';
$bldg_remove_modal_footer = '
    <button type="button" class="btn btn-admin" data-bs-dismiss="modal">Keep Building</button>
    <button type="button" class="btn btn-admin light_blue" id="bldg_remove_btn">Un-Feature Building</button>';
$bldg_remove_modal_option = array(
    'header_content' => 'Un-Feature This Building',
    'body_content' => $bldg_remove_modal__body,
    'footer_content' => $bldg_remove_modal_footer,
    'id' => 'bldg_remove_modal'
);
brixwork_modal_html($bldg_remove_modal_option);



// BUILDING SEARCH MODAL
$each_city_html = '';
$areas = get_areas(array('publish' => 1), 'name', 'ASC');
foreach ($areas as $area_id) {
    $each_city = new area;
    $each_city->initialize($area_id);
    $each_city_html .= '<option value="'.$each_city->id.'">'.$each_city->name.'</option>';
}

$bldg_search__body = <<<HTML
    <div>
        <p class="fs-6 mb-4">Search for a building by its name OR address</p>
    </div>
    <div class="search_name_wrapper">
        <label for="name" class="control-label orange">Search by Name</label>
        <input type="text" class="form-control buildings_search_field" name="name" id="name" placeholder="i.e. Aria Towers" size="40" />
    </div>
    <div class="search_address_wrapper row">
        <div class="col-xl-4 col-12">
            <label for="city" class="control-label orange">Search by Address</label>
            <select id="city" name="city" class="form-select buildings_search_field">
                <option value="">All Cities</option>
                $each_city_html
            </select>
        </div>
        <div class="col-xl-2 col-sm-6">
            <label for="number" class="control-label orange">Num</label>
            <input type="text" class="form-control buildings_search_field" name="number" id="number" placeholder="123" size="5" />
        </div>
        <div class="col-xl-2 col-sm-6">
            <label for="street_dir" class="control-label orange">Dir</label>
            <input type="text" class="form-control buildings_search_field" name="street_dir" id="street_dir" placeholder="W" size="5" />
        </div>
        <div class="col-xl-4 col-12">
            <label for="street" class="control-label orange">Street</label>
            <input type="text" class="form-control buildings_search_field" name="street" id="street" placeholder="Lonsdale Avenue" size="5" />
        </div>
    </div>
    
    <div id="building_search_list">
    </div>
HTML;

$bldg_search_option = array(
    'header_content' => 'Add or Search Building',
    'body_content' => $bldg_search__body,
    'id' => 'bldg_search_modal'
);
brixwork_modal_html($bldg_search_option);

include 'footer.php';
?>
