<?php
/**
 * Filename: buildings_mod.php
 * Description: Edit building data
 *
 * Accessibility: Usually Admin, Manager, and Content Manager is allowed.
 *                For Agent login, verify that the building allows the agent via dropdown.
 */
include 'start.php';
global $settings, $now, $mysqli;

$destinationtable = 'buildings';
$destinationfolder = 'buildings';

if ($_POST):
    $current_mode   = $_POST['mode'];           // either `new` or `modify`.
    $idr            = $_POST['idr'] ?: false;   // could be empty if `new`.
    $allow_submit   = true;                     // verify $_POST data and if not good, turn this variable to false and print error.

    $_POST['unittypes'] = array_to_delimited_options($_POST['types']);
    $_POST['feature'] = 1; // if user is entering it, chances are this is a featured building.

    // process street name, suffix, type etc.
    list($_POST['street_name'], $_POST['street_type'], $street_dir_burn, $_POST['street_suffix']) = separate_streetname($_POST['street']);
    list($_POST['showroom_street_name'], $_POST['showroom_street_type'], $street_dir_burn, $_POST['showroom_street_suffix']) = separate_streetname($_POST['showroom_street'] ?: '');

    // if new, set create_date & order
    if ($current_mode == 'new') {
        $_POST['create_date'] = $now;
        $mysqli->query("UPDATE `buildings` SET `ord` = `ord` +1 WHERE `feature` = 1 AND (`mainid` = 0 OR `mainid` = `id`)");
        $_POST['ord'] = 1;
        $_POST['timestamp'] = $now;
    }

    // convert empty values to null
    if($_POST['min_beds'] === ""){
        $_POST['min_beds'] = null;
    }
    if($_POST['max_beds'] === ""){
        $_POST['max_beds'] = null;
    }
    if($_POST['min_baths'] === ""){
        $_POST['min_baths'] = null;
    }
    if($_POST['max_baths'] === ""){
        $_POST['max_baths'] = null;
    }
    if($_POST['min_price'] === ""){
        $_POST['min_price'] = null;
    }
    if($_POST['max_price'] === ""){
        $_POST['max_price'] = null;
    }

    // process features...
    if (is_array($_POST['features'])) {
        // combine the selected features together into string to process in comma separated values.
        foreach($_POST['features'] as $key=>$value) {
            if($value!='' && $value!='null') {
                $features .= $value.',';
            }
        }
        $_POST['features'] = substr($features,0,strlen($features)-1);
    } else {
        $_POST['features'] = '';
    }

    // SUBMIT TO DATABASE
    if ($allow_submit) {
        $update_id = form_to_table($destinationtable, $_POST, $idr);

        if (is_numeric($update_id)) {
            $building = new building;
            $building->initialize($update_id);

            process_custom_fields($building);

            $post_title          = $_POST['name'] ?: $_POST['address'];
            $building_id_display = login_level_check(USER_LOGIN_BRIXWORK) ? '(ID: '.$update_id.')' : '';
            $status              = ($current_mode == 'new' && $idr === false) ? 'added' : 'modified';
            $_SESSION['success-message'] = "<p><b>Success!</b> The building data has been $status for <span style='text-decoration: underline'>$post_title $building_id_display</span>.</p>";

            // redirect & refresh the object data.
            header('Location:'.$settings['sitepath'].ltrim($_SERVER['PHP_SELF'], '/').'?idr='.$update_id);
            exit();
        } else {
            // updated failed ... create error message.
            $error = '<b>Error</b> There was an error while attempting to '.($current_mode=='modify' ? 'update' : 'create').' your new building. Error: <i>'.$update_id.'</i>. Please contact our support desk with this message.';
        }
    } else {
        $error = "<p><b>Warning!</b> Invalid value passed. Please verify your input or contact Brixwork Support.</p>";
    }
endif; // end if ($_POST)


// TODO: Add ?version='.$brixwork_version to js. AND minify!
// these scripts are only need when form is being edited ... do not include when the form is being submitted
$scriptinclude = array('brixwork_images.source.js', 'brixwork_attach.source.js', 'aws-sdk-2.40.0.min.js', 'buildings_mod.source.js');
$scriptinsert = '<script defer src="https://maps.googleapis.com/maps/api/js?key='.$settings['google_maps_api_key'].'&callback=initMap"></script>';

include "header.php";

$preset_object_type = "buildings";                          // essential variable
include "includes/object_mod_tabs/object_mod__prep.php";    // essential file inclusion

/**
 * @var $building building
 */
if ($building->mainid && ($building->id != $building->mainid)) {
    // if mainID of building is set, forward to that page! Cannot modify a sub-building.
    $main_bldg = new building;
    $main_bldg_init = $main_bldg->initialize($building->mainid);
    if ($main_bldg_init != false) {
        header("Location: ".$settings['sitepath'].'admin/buildings_mod.php?idr='.$main_bldg->id.'&mode=modify');
    } else {
        // If mainid is set but building doesn't exist, detach!
        echo 'DETACH!';
        $building->detach_building();
    }
}

// header_html is separated from header.php on purpose.
include 'includes/header_html.php';
?>
<form method="POST" role="form" id="buildings_mod_form" class="brixwork_admin_container mod_form" enctype="multipart/form-data" action="<?=$_SERVER['PHP_SELF']?>">
    <h1 id="admin_mod__title">
        <?php
        $building_name = 'Editing '.$building->name ?: $building->address.'<br/>'.$building->areacity;
        echo ($_GET['mode'] == 'new') ? 'Adding a New Building' : $building_name;
        ?>
    </h1>

    <?php
    // SUCCESS OR ERROR MESSAGE ON FORM SUBMIT.
    session_alert_display('success-message');

    if ($error)
        echo brixwork_alert($error, 'error');

    // BOOTSTRAP 5 TABS - Command + F to find HTML content for each tab
    $nav_tab_array = is_object($building) ? array('Basic Info', 'Location', 'Photos', 'Attachments', 'Showroom', 'SEO') : array('Basic Info', 'Location', 'Showroom', 'SEO');
    // INCLUDE LEADS & SALES TAB ONLY IF AGENT MODULE IS ACTIVE
    if ($settings['multiagents'] == 1) {
        array_splice($nav_tab_array, count($nav_tab_array)-1, 0, 'Leads & Access');
    }
    brixwork_object_tabs('building', $nav_tab_array);


    // ALL CORRESPONDING TAB CONTENTS ?>
    <div class="manage_object_tab_content tab-content">
        <?php // BASIC INFO CONTENT ?>
        <div class="manage_listing_each_tab tab-pane fade show active" id="basic-info-tab" role="tabpanel" aria-labelledby="Basic-Info" tabindex="0">
            <?php include "includes/object_mod_tabs/buildings_mod__basic_info.php"; ?>
        </div>

        <?php // DETAILS TAB CONTENT ?>
        <div class="manage_listing_each_tab tab-pane fade" id="location-tab" role="tabpanel" aria-labelledby="Details" tabindex="0">
            <?php include "includes/object_mod_tabs/buildings_mod__location.php"; ?>
        </div>

        <?php // PHOTOS TAB CONTENT ?>
        <div class="manage_listing_each_tab tab-pane fade" id="photos-tab" role="tabpanel" aria-labelledby="Photos" tabindex="0">
            <?php include "includes/object_mod_tabs/object_mod__photos.php"; ?>
        </div>

        <?php // ATTACHMENTS TAB CONTENT ?>
        <div class="manage_listing_each_tab tab-pane fade" id="attachments-tab" role="tabpanel" aria-labelledby="Attachments" tabindex="0">
            <?php include "includes/object_mod_tabs/object_mod__attach.php"; ?>
        </div>

        <?php // SHOWROOM TAB CONTENT ?>
        <div class="manage_listing_each_tab tab-pane fade" id="showroom-tab" role="tabpanel" aria-labelledby="Showroom" tabindex="0">
            <?php include "includes/object_mod_tabs/buildings_mod__showroom.php"; ?>
        </div>

        <?php // LEADS & SALES TAB CONTENT
        if ($settings['multiagents'] == 1):
        ?>
        <div class="manage_listing_each_tab tab-pane fade" id="leads-access-tab" role="tabpanel" aria-labelledby="Leads and Access" tabindex="0">
            <?php include "includes/object_mod_tabs/buildings_mod__sales.php"; ?>
        </div>
        <?php
        endif; //if ($settings['multiagents'] == 1):  ?>

        <?php // SEO TAB CONTENT ?>
        <div class="manage_listing_each_tab tab-pane fade" id="seo-tab" role="tabpanel" aria-labelledby="SEO" tabindex="0">
            <?php include "includes/object_mod_tabs/object_mod__seo.php"; ?>
        </div>
    </div>

    <div id="submit_button_group" class="">
        <?php // HIDDEN INPUT TO BE USED IN $_POST
        if (is_object($building)) {
            $idr_val = $building->id;
            $mode_val = 'modify';
        } else {
            $idr_val = "";
            $mode_val = 'new';
        }
        echo "<input type='hidden' name='idr' id='idr' value='$idr_val' />";
        echo "<input type='hidden' name='mode' value='$mode_val' />";
        ?>
        <input type="submit" name="submitform" id="pagesubmit" class="btn btn-admin" value="<?=$mode_val == 'new' ? 'Add Building' : 'Save Building'?>" />
        <a class="btn btn-admin light_blue" href="buildings.php">Back</a>
    </div>
</form>



<?php
// BUILD MODAL FOR DETACHING SUB-BUILDING
$make_primary_body = '<p>Are you sure you want to change the primary building of this group?</p><p class="text-danger">Note that the name, builder, description &amp; content, features, photos etc. will be derived from the Primary Building that groups the sub-buildings.</p>';
$make_primary_footer = '
    <button type="button" class="btn btn-admin" data-bs-dismiss="modal">Cancel</button>
    <button type="button" class="btn btn-admin light_blue" data-bs-dismiss="modal" id="make_primary_btn">Set this Building as Primary</button>';
$make_primary_option = array(
    'header_content' => 'Set this Sub-building as Primary',
    'body_content' => $make_primary_body,
    'footer_content' => $make_primary_footer,
    'id' => 'make_primary_building'
);
brixwork_modal_html($make_primary_option);



// BUILD MODAL FOR DETACHING SUB-BUILDING
$detach_building__body = '<p>Are you sure you want to detach the selected building from '.$building->name.'?</p><p class="text-danger">Once detached, the detached building will need to be edited independently. In general, you would only do this if you grouped this building by mistake.</p></p>';
$detach_building__footer = '
    <button type="button" class="btn btn-admin" data-bs-dismiss="modal">Cancel</button>
    <button type="button" class="btn btn-admin light_blue" data-bs-dismiss="modal" id="detach_building_btn">Detach Building</button>';
$detach_building__option = array(
    'header_content' => 'Detach this Sub-Building?',
    'body_content' => $detach_building__body,
    'footer_content' => $detach_building__footer,
    'id' => 'detach_building'
);
brixwork_modal_html($detach_building__option);


// BUILD MODAL FOR DELETING OTHER FEATURE
$delete_listing_feature__body = '<p>Are you sure you want to delete? The feature will be removed from ALL the listings & buildings.</p><p>Consider unchecking instead</p>';
$delete_listing_feature__footer = '
    <button type="button" class="btn btn-admin" data-bs-dismiss="modal">Keep Feature</button>
    <button type="button" class="btn btn-admin light_blue" data-bs-dismiss="modal" id="remove_listing_feature">Delete Feature</button>';
$delete_listing_feature__options = array(
    'header_content' => 'Delete this feature?',
    'body_content' => $delete_listing_feature__body,
    'footer_content' => $delete_listing_feature__footer,
    'id' => 'delete_feature'
);
brixwork_modal_html($delete_listing_feature__options);


/**
 * HELPER FUNCTION FOR BUILDING
 * Get published list of cities for the building
 * @param $building
 * @return array|bool
 */
function get_published_cities($building): array|bool {
    $location_query['publish'] = 1;
    if ($_REQUEST['city'] != '') {
        $location_query['id'] = $_REQUEST['city'];
    }
    if ($building->data['city'] != '') {
        $location_query['id'] = $building->data['city'];
    }
    return get_areas($location_query);
}

/**
 * DISPLAY PUBLISHED CITIES IN "SELECT" DROPDOWN
 * @param bool|array $cities
 * @param $building
 * @param $data         string  building-data to get
 * @return void
 */
function select_published_cities(bool|array $cities, $building, string $data): void {
    foreach ($cities as $city_id) {
        $city = new area;
        $city->initialize($city_id);
        $selected_text = ($building->data[$data] == $city->id || $_REQUEST['city'] == $city->id) ? 'selected' : '';

        echo '<option value="' . $city_id . '"' . $selected_text . '>' . $city->name . '</option>';
    }
}

include 'footer.php';