<?php
/*
Filename: homes_mod.php

Method: Direct
Output: Direct

Description: Add new listing or edit an existing listing, by MLS import or by direct entry.

Author: Jeff Kee
*/

include 'start.php';
global $settings;
global $login_user;

$destinationtable = 'homes';
$destinationfolder = 'homes';


// ON FORM SUBMIT, $POST WILL BE CREATED.
$error_message = $error = '';
if ($_GET['add'] == 'success' && $_GET['idr']) {
    // this runs after the new object has been added ... $home object is initialized at the top.
    $success = "<p><b>Success!</b> The listing data has been added for <span style='text-decoration: underline'>$home->mls</span></p>";
}


if ($_POST):
    $current_mode   = $_POST['mode'];           // either `new` or `modify`.
    $idr            = $_POST['idr'] ?: false;   // could be empty if `new`.
    $allow_submit   = true;                     // verify $_POST data and if not good, turn this variable to false and print error.

    $_POST['modify_date']   = $now;           // modify date is always "now".
    $_POST['timestamp']     = $_POST['modify_date'];
    $_POST['phpfile']       = $_SERVER['SCRIPT_NAME'];
    $_POST['mls']           = strtoupper($_POST['mls']); // MLS # auto converts to uppercase!

    // if new, set create_date & order
    if ($current_mode == 'new') {
        $_POST['create_date'] = $now;
        $mysqli->query("UPDATE homes SET `ord` = `ord`+1 WHERE source = 0 OR (source = 1 AND feature = 1)");
        $_POST['ord'] = 0.5;
    }

    if ($_POST['street_dir_position']=='') {
        unset($_POST['street_dir_position']); // unset it, so it doesn't default to 0!!! if blank, leave it blank.
    }

    // process street name, suffix, type etc.
    list($_POST['street_name'], $_POST['street_type'], $street_dir_burn, $_POST['street_suffix']) = separate_streetname($_POST['street']);

    // process features...
    if (is_array($_POST['features'])) {
        // combine the selected features together into string to process in comma separated values.
        foreach ($_POST['features'] as $key => $value) {
            if ($value != '' && $value != 'null') {
                $features .= $value . ',';
            }
        }
        $_POST['features'] = substr($features, 0, strlen($features) - 1);
    } else {
        $_POST['features'] = '';
    }

    // process the feature boolean fields.
    foreach($settings['home_features'] as $feature_field) {
        if ($_POST[$feature_field] == 'on') {
            $_POST[$feature_field] = 1;
        } else {
            $_POST[$feature_field] = 0;
        }
    }

    // dimension aggregator  = bedroom:12'X10';master:14'X12';  will be the format.
    $count=0;
    $_POST['dimension'] = '';
    while($count < $settings['roomsizetotal']) {
        $char_to_replace = array(";", ":", '"'); // just remove the double quote as well. Most people will understand that 10'7 means 10'7" or 10 feet 7 inches.
        //$room_label = htmlspecialchars(str_replace($char_to_replace, "", $_POST['room'][$count]), ENT_COMPAT);  // this is the most logical fix, however we separate each row of dimensions with ";", which is the major problem.
        //$room_size  = htmlspecialchars(str_replace($char_to_replace, "", $_POST['size'][$count]), ENT_COMPAT);  // ENT_COMPAT is PHP constant for skipping single quote (apostrophe) and only replace double quote.
        $room_label = str_replace($char_to_replace, "", $_POST['room'][$count]);
        $room_size  = str_replace($char_to_replace, "", $_POST['size'][$count]);
        $_POST['dimension'] .= $room_label .":". $room_size .";";
        $count++;
    }

    // If all agents are empty, do not submit. -- not all clients have agents activated ... although we should manually update those without it.
//    if (!$_POST['agent_1'] && !$_POST['agent_2'] && !$_POST['agent_3']) {
//        $allow_submit = false;
//        $error_message = "<p><b>Warning!</b> Listings must have at least one agent associated.</p>";
//    }

    // ON SUBMIT BEHAVIOR
    if ($allow_submit) {
        $update_id = form_to_table($destinationtable, $_POST, $idr);

        if (is_numeric($update_id)) {
            $home = new home;
            $home->initialize($update_id);

            process_custom_fields($home);

            // different success messages depending on "created" or "modified"
            $post_title = $_POST['mls'] ?: $_POST['address'];
            $home_id_display = login_level_check(1) ? '(ID: '.$update_id.')' : '';
            $status = ($current_mode == 'new' && $idr === false) ? 'added' : 'modified';
            $_SESSION['success-message'] = "<p><b>Success!</b> The listing data has been $status for <span style='text-decoration: underline'>$post_title $home_id_display</span>.</p>";

            // redirect & refresh the object data.
            header('Location:'.$settings['sitepath'].ltrim($_SERVER['PHP_SELF'], '/').'?idr='.$update_id);
            exit();

        } else {
            // updated failed ... create error message.
            $error = '<p><b>Error</b> There was an error while attempting to '.($_GET['mode']=='modify' ? 'update' : 'create').' your new listing. Error: <i>'.$update_id.'</i>. Please contact our support desk with this message.</p>';
        }
    } else {
        $error = $error_message;
    }
endif; // END IF $POST

// TODO: Add ?version='.$brixwork_version to js. AND minify!
// these scripts are only need when form is being edited ... do not include when the form is being submitted
$scriptinclude = array('brixwork_images.source.js', 'homes_mod.source.js', 'aws-sdk-2.40.0.min.js', 'brixwork_attach.source.js');
$scriptinsert = '<script defer src="https://maps.googleapis.com/maps/api/js?key='.$settings['google_maps_api_key'].'&callback=initMap"></script>';


include 'header.php';

$preset_object_type = "homes";                              // essential variable
include "includes/object_mod_tabs/object_mod__prep.php";    // essential file inclusion


/**
 * @var $home home      OBJECT CREATED IN object_mod__prep.php
 * How to redirect invalid user?
 * Invalid user =
 * 1. associated agent IDs of the login user do not match with listings agents
 * 2. Admin/Manager cannot be invalid user - they have access to all listings at all times.
 *
 * Note
 * 1. Exclude this function for Admin/Manager - they have access to all listings at all times.
 * 2. Exclude when creating new listings.
 *
 * Required data
 * 1. $home object to determine which agents have access to the homes
 * 2. $login_user object initiated in start.php
 */
if ($_GET['mode'] != 'new' && !login_level_check(USER_LOGIN_MANAGER)) {
    $home_agents_array = array($home->data['agent_1'], $home->data['agent_2'], $home->data['agent_3']);
    $agent_access = !empty(array_intersect($login_user->getAgents(), $home_agents_array));

    if (!$agent_access) {
        header('Location:'.$settings['sitepath'].'admin/');
        exit();
    }
}

// header_html is separated from header.php on purpose.
include 'includes/header_html.php';
?>
    <form method="POST" role="form" id="homes_mod_form" class="brixwork_admin_container mod_form" enctype="multipart/form-data" action="<?=$_SERVER['PHP_SELF']?>">
        <h1 id="admin_mod__title">
            <?php if($_GET['mode']=='new') {echo 'Adding A New Listing'; } else {echo 'Editing '.$home->address.'<br/>'.$home->areacity;} ?>
        </h1>

        <?php
        // SUCCESS OR ERROR MESSAGE ON FORM SUBMIT.
        session_alert_display('success-message');

        if ($error)
            echo brixwork_alert($error, 'error');

        // BOOTSTRAP 5 TABS - Command + F to find HTML content for each tab
        $nav_tab_array = is_object($home) ? array('Basic Info', 'Details', 'Photos', 'Attachments', 'Rental', 'Commercial', 'Dimensions', 'SEO') : array('Basic Info', 'Details', 'Rental', 'Commercial', 'Dimensions', 'SEO');
        brixwork_object_tabs('home', $nav_tab_array);
        ?>

        <?php // ALL CORRESPONDING TAB CONTENTS ?>
        <div class="manage_object_tab_content tab-content">
            <?php // BASIC INFO CONTENT ?>
            <div class="manage_listing_each_tab tab-pane fade show active" id="basic-info-tab" role="tabpanel" aria-labelledby="Basic-Info" tabindex="0">
                <?php include "includes/object_mod_tabs/homes_mod__basic_info.php"; ?>
            </div>

            <?php // DETAILS TAB CONTENT ?>
            <div class="manage_listing_each_tab tab-pane fade" id="details-tab" role="tabpanel" aria-labelledby="Details" tabindex="0">
                <?php include "includes/object_mod_tabs/homes_mod__details.php"; ?>
            </div>

            <?php // PHOTOS TAB CONTENT
            if (is_object($home)) { ?>
                <div class="manage_listing_each_tab tab-pane fade" id="photos-tab" role="tabpanel" aria-labelledby="Photos" tabindex="0">
                    <?php include "includes/object_mod_tabs/object_mod__photos.php"; ?>
                </div>

                <?php // ATTACHMENTS TAB CONTENT ?>
                <div class="manage_listing_each_tab tab-pane fade" id="attachments-tab" role="tabpanel" aria-labelledby="Attachments" tabindex="0">
                    <?php include "includes/object_mod_tabs/object_mod__attach.php"; ?>
                </div>
                <?php
            } ?>

            <?php // RENTALS TAB CONTENT ?>
            <div class="manage_listing_each_tab tab-pane fade" id="rental-tab" role="tabpanel" aria-labelledby="Rental" tabindex="0">
                <?php include "includes/object_mod_tabs/homes_mod__rental.php"; ?>
            </div>

            <?php // COMMERCIAL TAB CONTENT ?>
            <div class="manage_listing_each_tab tab-pane fade" id="commercial-tab" role="tabpanel" aria-labelledby="Commercial" tabindex="0">
                <?php include "includes/object_mod_tabs/homes_mod__commercial.php"; ?>
            </div>

            <?php // DIMENSIONS TAB CONTENT ?>
            <div class="manage_listing_each_tab tab-pane fade" id="dimensions-tab" role="tabpanel" aria-labelledby="Dimensions" tabindex="0">
                <?php include "includes/object_mod_tabs/homes_mod__dimensions.php"; ?>
            </div>

            <?php // SEO TAB CONTENT ?>
            <div class="manage_listing_each_tab tab-pane fade" id="seo-tab" role="tabpanel" aria-labelledby="SEO" tabindex="0">
                <?php include "includes/object_mod_tabs/object_mod__seo.php"; ?>
            </div>
        </div>

        <div id="submit_button_group" class="">
            <?php // HIDDEN INPUT TO BE USED IN $_POST
            if (is_object($home)) {
                $idr_val = $home->id;
                $mode_val = 'modify';
            } else {
                $idr_val = "";
                $mode_val = 'new';
            }
            echo "<input type='hidden' name='idr' id='idr' value='$idr_val' />";
            echo "<input type='hidden' name='mode' value='$mode_val' />";
            ?>
            <input type="submit" name="submitform" id="pagesubmit" class="btn btn-admin" value="<?=$mode_val == 'new' ? 'Add Listing' : 'Save Listing'?>" />
            <a class="btn btn-admin light_blue" href="homes.php">Back</a>
        </div>
    </form>




<?php
// MODAL HTML
brixwork_modal_html(array(
    'header_content' => 'Building Not Found',
    'body_content' => '
        <p>The given address for this building or townhome division has not been found in the system. Do you want to add this one?</p>
        <div class="building_name_wrapper">
            <form id="new_building__name" class="needs-validation" novalidate>
                <label for="building_name" class="control-label orange">Building Name (Required)</label>
                <input autocomplete="off" type="text" name="building_name" id="building_name" class="form-control" tabindex="0" value="" placeholder="Name of building here" required/>
                <div class="invalid-feedback">Building name is required!</div>
            </form>
        </div>',
    'footer_content' => '
        <button type="button" class="btn btn-admin px-4" data-bs-dismiss="modal">Not Now</button>
        <button type="submit" form="new_building__name" class="btn btn-admin light_blue px-4 create_new_building">Add new building</button>',
    'id' => 'building_notfound'
));


// MODAL FOR OVERRIDING AUTOMATICALLY CALCULATED LEASE PRICE
$lease_override_body = '<p>Our system calculates the monthly lease from the base $/sqft plus additional lease $/sqft. Would you like to manually input your own anyway?</p>';
$lease_override_footer = '
    <button type="button" class="btn btn-admin" data-bs-dismiss="modal">Keep the Calculated Value</button>
    <button type="button" class="btn btn-admin light_blue" data-bs-dismiss="modal" onclick="commercial_lease_calculate(true)">Input Manually</button>';
$lease_override_option = array(
    'header_content' => 'Override Lease Rate Manually?',
    'body_content' => $lease_override_body,
    'footer_content' => $lease_override_footer,
    'id' => 'commercial_lease_override'
);
brixwork_modal_html($lease_override_option);

// after edit is done (on confirmation page)
//$building_edit = 'edit_building(window.buildingid);';
//$back_to_list = js_redirect('homes.php', 100, true);
//modal_html('Building Name Not Set', 'To be filled in by javascript on fly', 'building_edit', 'Edit Building', 'Not Now', $building_edit, $back_to_list);

// BUILD MODAL FOR DELETING OTHER FEATURE
$delete_listing_feature__body = '<p>Are you sure you want to delete? The feature will be removed from ALL the listings & buildings.</p><p>Consider unchecking instead</p>';
$delete_listing_feature__footer = '
    <button type="button" class="btn btn-admin" data-bs-dismiss="modal">Keep Feature</button>
    <button type="button" class="btn btn-admin light_blue" data-bs-dismiss="modal" id="remove_listing_feature">Delete Feature</button>';
$delete_listing_feature__options = array(
    'header_content' => 'Delete this feature?',
    'body_content' => $delete_listing_feature__body,
    'footer_content' => $delete_listing_feature__footer,
    'id' => 'delete_feature'
);
brixwork_modal_html($delete_listing_feature__options);

include 'footer.php';