/**
 * COMBINATION OF GALLERY.JS & MAIN-IMAGE.JS
 *
 * 2023 BACKEND UPGRADE HAS ALL PHOTO FUNCTIONS IN ONE PAGE ... COMBINE THE TWO JAVASCRIPT!
 */
$(document).ready(function(){
    console.log('brixwork_attach.js is running with destination folder set as: ' + window.destinationfolder);

    // initialize pdf attachment functions
    let pdf_upload_ui = document.querySelectorAll('[id^="pdf_input"]')
    pdf_upload_ui.forEach(init_pdf_attach)

    // initialize YouTube and Vimeo attachment functions
    let video_upload_ui = document.querySelectorAll('.video_upload_js')
    video_upload_ui.forEach(init_video_attach)

    // Virtual Tour Attach & Remove function ... only for homes ( and maybe buildings )
    if (window.destinationfolder === 'homes') {
        let virtual_tour_attach = document.getElementById('update_virtual_tour')
        let virtual_tour_remove = document.getElementById('remove_virtual_tour')
        let virtual_tour_input = document.getElementById('virtualtour')
        if (virtual_tour_attach) {
            virtual_tour_attach.addEventListener('click', function () {
                update_virtual_tour(virtual_tour_input.value)
            })
        }
        if (virtual_tour_remove) {
            virtual_tour_remove.addEventListener('click', function () {
                update_virtual_tour('')
            })
        }
    }
});

/**
 * INITIALIZE PDF ATTACHMENT UPLOAD & DELETE
 * @param each_upload
 */
function init_pdf_attach(each_upload) {
    let count = each_upload.dataset.count
    let sequence = count > 0 ? count : '';          // when count is 0, suffix is empty string.
    let filename = each_upload.dataset.filename
    let pdf_exists = each_upload.dataset.uploaded

    // different button html depending on pdf exist
    let buttonText = pdf_exists ?
        '<div class="upload_text d-flex flex-column" id="pdf_upload_info'+sequence+'">' +
        '   <i class="bi bi-filetype-pdf"></i>' +
        '   <h3>Uploaded</h3>' +
        '   <a href="#">Replace PDF</a>' +
        '</div>' :
        '<div class="upload_text d-flex flex-column" id="pdf_upload_info'+sequence+'">' +
        '   <i class="bi bi-cloud-upload"></i>' +
        '   <h3>Drag & Drop</h3>' +
        '   <a href="#">Select PDF</a>' +
        '</div>'

    let buttonClass = pdf_exists ? ' pdf_exists' : '';


    $(each_upload).uploadifive({
        'uploadScript' : '/admin/ajax_uploadify.php',
        'auto' : true,
        'buttonClass': 'btn btn-block uploadifiveinput' + buttonClass,
        'buttonText':   buttonText,
        'method': 'post',
        'multi':false,
        'fileObjName': 'Filedata',
        'height': '200',
        'width': '100%',
        'queueSizeLimit': 1,
        'fileType': ['application/pdf'],
        'removeCompleted': true,
        'queueID': 'pdfqueue'+sequence,
        'itemTemplate' : '<p class="uploadifive-queue-item bg-brixwork-grey-teal">Currently Uploading <span class="filename"></span></p>',
        'formData': {'homeid':window.idr, 'idr':window.idr, 'filename': filename, 'destinationfolder': window.destinationfolder},
        'onAddQueueItem' : function(file) {
            console.log('uploading file check');
            $('#pdfprogressbar'+sequence).css('width', '0%').attr('aria-valuenow', 0);
            let file_name = file.name;
            let file_ext = file_name.substring(file_name.lastIndexOf('.')+1,file_name.length); // Extract EXT main_detail.jpg rejects .jpeg
            file_ext = file_ext.toLowerCase();
            console.log('checking ext: '+file_ext);

            switch (file_ext) {
                case 'pdf':
                    console.log('filetype ok');
                    break;
                default:
                    $('#pdf_input'+sequence).uploadifive('cancel', file); // cancel current upload,
                    $('#filetype_pdf').modal('show');
                    break;
            }
        },
        'onProgress': function (file, e) {
            let percentage = (e.loaded/e.total)*100;
            $('#pdfprogressbar'+sequence).css('width', percentage+'%').attr('aria-valuenow', percentage);
        },
        'onCancel': function() {
            $('#pdfprogressbar'+sequence).css('width', '0%').attr('aria-valuenow', 0);
        },
        'onError': function(errorType) {
            console.log(errorType);
        },
        'onUploadComplete': function (file, data) {
            //console.log(data);
            console.log("Upload Success");
            $('#pdfprogressbar'+sequence).css('width', '100%').attr('aria-valuenow', 100).delay(1000).css('width', '0%').attr('aria-valuenow', 0);
            $('#pdf_preview'+sequence).html('<a href="'+data+'" target="_blank" class="">Preview '+filename+'</a>');
            document.getElementById('pdf_upload_info'+sequence).innerHTML =
                '<i class="bi bi-filetype-pdf"></i>' +
                '<h3>Uploaded</h3>' +
                '<a href="#">Replace PDF</a>'
            document.getElementById('uploadifive-pdf_input'+sequence).style.backgroundColor = "#d7d7d7"
            document.getElementById('removepdf'+sequence).classList.remove('disabled') // enable delete button
        },
    })

    let uploadifive_pdf = document.getElementById('uploadifive-pdfinput'+sequence)
    $(uploadifive_pdf).bind('dragover', function(){
        $(this).addClass('dragover')
    })
    $(uploadifive_pdf).bind('dragleave', function(){
        $(this).removeClass('dragover')
    })
    $(uploadifive_pdf).bind('drop', function(){
        $(this).removeClass('dragover')
    })

    // DELETE PDF FUNCTION
    $('#removepdf'+sequence).click(function(){
        remove_s3_file(window.destinationfolder, window.idr, 'pdf', count)
        document.getElementById('pdf_upload_info'+sequence).innerHTML =
            '<i class="bi bi-cloud-upload"></i>' +
            '<h3>Drag & Drop</h3>' +
            '<a href="#">Select PDF</a>'
        $('#pdf_preview'+sequence).html('');
        document.getElementById('uploadifive-pdf_input'+sequence).style.backgroundColor = "#ffffff"
    });


    // UPDATE LABEL FUNCTION
    let update_label_button = document.getElementById('update_pdflabel'+sequence)
    let pdf_label = document.getElementById('pdf_label'+sequence)

    pdf_label.addEventListener('focus', function () {
    //     update_label_button.removeAttribute('disabled');
        update_label_button.innerText = "Update Label";
    })

    // input field out of focus disables the update button.
    pdf_label.addEventListener('blur', function () {
        // update_label_button.setAttribute('disabled', 'disabled');
        update_label_button.innerText = "Update Label";
    })

    update_label_button.addEventListener('click', function () {
        //console.log('update label initiated at ' + sequence);
        let new_label = pdf_label.value;
        $.post(
            'ajax_modify'+window.destinationfolder+'.php',
            {change:'pdf_label', value: new_label, key: count, idr: window.idr},
            function(data){
                // blink to show success!
                if(data.code === 1) {
                    console.log('update success')
                    update_label_button.innerText = "Updated";
                } else {
                    console.log('update failed: ' + data.message);
                }
            }, 'json'
        );
    })
}


function init_video_attach(each_video) {
    let type = each_video.dataset.type      // youtube or vimeo
    let count = each_video.dataset.count
    let sequence = count > 0 ? count : ''   // or "suffix" ... should be empty string for first, add numbers for after

    let link_btn
    let remove_btn
    let video_input

    // attach the video to div
    if (type === 'youtube') {
        link_btn = document.getElementById('updateyoutube'+sequence)
        remove_btn = document.getElementById('removeyoutube'+sequence)
        video_input = document.getElementById('youtube'+sequence)
    }
    else if (type === 'vimeo'){
        link_btn = document.getElementById('updatevimeo'+sequence)
        remove_btn = document.getElementById('removevimeo'+sequence)
        video_input = document.getElementById('vimeo'+sequence)
    }

    link_btn.addEventListener('click', function () {
        update_video(video_input.value, window.idr, type, sequence)
    })
    remove_btn.addEventListener('click', function () {
        update_video('', window.idr, type, sequence)
    })
}

/**
 * ON CLICK "LINK" FOR YOUTUBE ...
 * @param val       youtube link
 * @param idr       get from window.idr
 * @param field     $settings[$object_type.'_youtubefields'][$youtube_counter] ... either "youtube" or "vimeo"
 * @param suffix    sequence
 */
function update_video(val, idr, field, suffix) {
    $.post(
        'ajax_modify' + window.destinationfolder + '.php',
        {change: field, idr: idr, field: field, value: val},
        function (data) {
            let video_id = data.message;
            console.log(field + ' updated to ' + video_id);
            update_preview_frame(field, video_id, suffix);
        }, 'json'
    );
}


/**
 * Run this function on click of "Link" button for virtual tour.
 * @param val   Link of the virtual tour
 */
function update_virtual_tour(val) {
    $.post(
        'ajax_modify'+window.destinationfolder+'.php',
        {change:'virtualtour', idr:window.idr, value: val},
        function(data){
            let src_link = data.message;
            console.log('virtual tour link for '+idr+' updated to '+src_link)
            update_preview_frame('virtualtour', src_link, '')
        }, 'json'
    );
}


/**
 * Create Video Iframe HTML with processed Video ID
 * @param type          YouTube or Vimeo
 * @param video_id      Processed Video ID
 * @param suffix        sequence id of the preview div
 * @return {string}     iFrame HTML block
 */
function update_preview_frame(type, video_id, suffix) {
    switch (type) {
        case 'youtube':
            let youtube_preview_div = document.getElementById('youtube_preview'+suffix)
            let youtube_input_div = document.getElementById('youtube'+suffix)
            let youtube_frame = '';

            if (video_id !== '' && video_id !== undefined) {
                youtube_preview_div.classList.remove('no_preview');
                youtube_frame =
                    '<iframe class="responsive_iframe" width="560" height="315" src="https://www.youtube.com/embed/' + video_id + '" title="' + window.destinationfolder + ' youtube video" allow="accelerometer; clipboard-write; encrypted-media; gyroscope; picture-in-picture; web-share" allowfullscreen></iframe>'
                youtube_input_div.value = video_id;
            } else {
                youtube_preview_div.classList.add('no_preview');
                youtube_frame =
                    '<div class="responsive_iframe no_preview"><i class="bi bi-play-circle"></i></div>'
                youtube_input_div.value = '';
            }

            youtube_preview_div.innerHTML = youtube_frame;
            break

        case 'vimeo':
            let vimeo_preview_div = document.getElementById('vimeo_preview'+suffix)
            let vimeo_input_div = document.getElementById('vimeo'+suffix)
            let vimeo_frame = ''

            if (video_id !== '' && video_id !== undefined) {
                vimeo_preview_div.classList.remove('no_preview');
                vimeo_frame =
                    '<iframe class="responsive_iframe" src="https://player.vimeo.com/video/' + video_id + '?h=c81dd19e39&amp;badge=0&amp;autopause=0&amp;player_id=0&amp;app_id=58479" width="560" height="315" frameborder="0" allow="autoplay; fullscreen; picture-in-picture" allowfullscreen title="' + window.destinationfolder + ' vimeo video"></iframe>'
                vimeo_input_div.value = video_id
            } else {
                vimeo_preview_div.classList.add('no_preview');
                vimeo_frame =
                    '<div class="responsive_iframe no_preview"><i class="bi bi-play-circle"></i></div>'
                vimeo_input_div.value = '';
            }

            vimeo_preview_div.innerHTML = vimeo_frame;
            break

        case 'virtualtour':
            let virtual_preview_div = document.getElementById('virtual_tour_preview')
            let virtual_input_div = document.getElementById('virtualtour')
            let virtual_tour_frame = ''

            if (video_id !== '' && video_id !== undefined) {
                virtual_preview_div.classList.remove('no_preview');
                virtual_tour_frame =
                    '<iframe class="responsive_iframe" src="'+video_id+'" width="560" height="315" frameborder="0" allow="autoplay; fullscreen; picture-in-picture" allowfullscreen title="<?=$object_type?> virtual tour"></iframe>'
                virtual_preview_div.value = video_id
            } else {
                virtual_preview_div.classList.add('no_preview');
                virtual_tour_frame =
                    '<div class="responsive_iframe no_preview"><i class="bi bi-play-circle"></i></div>'
                virtual_input_div.value = '';
            }
            virtual_preview_div.innerHTML = virtual_tour_frame;
            break
    }
}