let office_map, marker, mls_search_map, mls_marker	// map variable is created by initMap() called by googleapis.

$(document).ready(function(){
	// original lat long data from the map created by initMap()
	let lat_origin = office_map.center.lat()
	let lng_origin = office_map.center.lng()
	let lat_origin_mls = mls_search_map.center.lat()
	let lng_origin_mls = mls_search_map.center.lng()


	// Focus already pinned location again - does not use geocode API.
	$('#reset_map').click(function () {
		display_map_origin(office_map, lat_origin, lng_origin)
	})
	$('.mls_search_map_reset').click(function () {
		display_map_origin(mls_search_map, lat_origin_mls, lng_origin_mls)
	})
	// Pin map using geocode API on click
	$('#find_address_on_map').click(display_address_on_map)


	$(window).keydown(function(event){
		if(event.keyCode === 13) {
			event.preventDefault();
			return false;
		}
	});


	// $('.form-check-input').click(function () {
	// 	console.log($(this).attr('value') + ' with id: ' + $(this).attr('id'))
		// let new_val = parseInt($(this).attr('value')) === 1 ? 0 : 1
		// $(this).val(new_val)
	// })


	$('.settings_form').submit(function() {
		window.leaveflag=1;
		$(this).find('#settingsubmit').attr('disabled', 'disabled').attr('value','processing...');
		return true;
	});

	// FUNCTIONS FOR SETTINGS_TEXT_2023
	// make all input list sortable.
	let input_list = $("[id$='-wrapper']")
	input_list.each(function () {
		let name = $(this).attr('id')
		init_setting_sortable(name)
	})
	init_setting_edit()
	init_setting_add()
	init_setting_delete()

	// FUNCTIONS FOR ADMIN_MULTI_INPUT
	init_multi_input_add()
	init_multi_input_delete()

	// S3 FOLDER NAME CHANGE
	init_s3_change()
});


function initMap() {
	// this initmap function is ran by the script include BEFORE the header.php
	let office_map_data = document.getElementById('officemapcontainer')
	let office_lat    = parseFloat(office_map_data.dataset.lat)
	let office_long   = parseFloat(office_map_data.dataset.long)

	office_map = new google.maps.Map(document.getElementById("officemap"), {
		center: {lat: office_lat, lng: office_long},
		zoom: 16,
	})
	marker = new google.maps.Marker({
		position: { lat: office_lat, lng: office_long },
		map: office_map,
	});

	// MLS SEARCH DEFAULT MAP INIT
	let map_search_data = document.getElementById('map_search_container')
	let map_search_lat    = parseFloat(map_search_data.dataset.lat)
	let map_search_long   = parseFloat(map_search_data.dataset.long)

	mls_search_map = new google.maps.Map(document.getElementById("map_search"), {
		center: {lat: map_search_lat, lng: map_search_long},
		zoom: 14,
	})
	mls_marker = new google.maps.Marker({
		position: { lat: map_search_lat, lng: map_search_long },
		map: mls_search_map,
	});

	// Listen for the map's center to change
	google.maps.event.addListener(mls_search_map, 'bounds_changed', function() {
		mls_marker.setPosition(mls_search_map.getCenter());
	});
	google.maps.event.addListener(mls_search_map, 'idle', function () {
		// get the new position.
		let new_position = mls_marker.getPosition()
		update_mls_lat_long(new_position)
	})

	// Listen for the map's center to change
	google.maps.event.addListener(office_map, 'bounds_changed', function() {
		marker.setPosition(office_map.getCenter());
	});
	google.maps.event.addListener(office_map, 'idle', function () {
		// get the new position.
		let new_position = marker.getPosition()
		update_office_lat_long(new_position)
	})

	console.log('Initialized Google Map Objects')
}

/**
 * DISPLAY INPUT ADDRESS ON THE MAP.
 * @return {Promise<void>}
 */
async function display_address_on_map() {
	let number 		= document.getElementById('address_2').value
	let address		= document.getElementById('address1').value;
	let city		= document.getElementById('office_city').value;
	let location	= document.getElementById('province').value
	let country		= document.getElementById('country').value

	let latitude, longitude;
	if (address) {
		let geocoder = new google.maps.Geocoder();
		await geocoder.geocode({ 'address': number+' '+address+', '+city+', '+location+', '+country }, function(results, status) {
			if (status === google.maps.GeocoderStatus.OK) {
				// Successful geocoding
				latitude = results[0].geometry.location.lat();
				longitude = results[0].geometry.location.lng();
				console.log(number+' '+address+', '+city+', '+location+', '+country)
				console.log("Latitude: " + latitude + "\nLongitude: " + longitude);
			} else {
				// Geocoding failed
				console.log("Geocode was not successful for the following reason: " + status);
			}
		});
	}

	// UPDATE VALUE
	document.getElementById('lat').value = latitude
	document.getElementById('long').value = longitude

	// UPDATE MAP AND MARKER
	let newLatLng = new google.maps.LatLng(latitude, longitude)
	marker.setPosition(newLatLng)
	office_map.setCenter(newLatLng)
}

/**
 * ORIGINAL MAP POSITION USING INITIAL LAT LONG VALUE
 */
function display_map_origin(map, lat_origin, lng_origin) {
	let lat_lng_origin = new google.maps.LatLng(lat_origin, lng_origin);
	map.setCenter(lat_lng_origin)
}


window.onbeforeunload = function() {
	if(window.leaveflag!==1) {
    	return 'Are you sure you want to leave this page? There may be unsaved changes on this page content.';
    }
}

// make each list of input sortable
function init_setting_sortable(input_name) {
	let sortable_div = '#' + input_name

	$(sortable_div).sortable({
		items: ".settings_each_input",
		handle: ".orderhandle",
		cursor: 'move',
		update: function () {
			let input_order_vars = $(sortable_div).sortable('serialize');
			console.log(input_order_vars + ' is vars');
		}
	});
}

/**
 * toggle delete & sort & add buttons on click of EDIT button
 */
function init_setting_edit() {
	let settings_edit_button = $(".edit_setting_array")
	onclick_edit(settings_edit_button)
}

function onclick_edit(div) {
	div.each(function () {
		let rel = $(this).attr('rel')
		let delete_button = $('.delete_setting_array[rel="'+rel+'"]')
		let re_order_button = $('.orderhandle[rel="'+rel+'"]')
		let add_button = $('.add_setting_array[rel="'+rel+'"]')

		$(this).on('click',function () {
			$(delete_button).toggleClass('d-none')
			$(re_order_button).toggleClass('d-none')
			$(add_button).toggleClass('d-none')
		})
	})
}

/**
 * CREATE NEW INPUT FIELD ON CLICK OF "ADD" BUTTON
 */
function init_setting_add() {
	let settings_add_button = $('.add_setting_array')

	settings_add_button.each(function () {
		let rel = $(this).attr('rel')
		let parent_div = $("#" + rel + "-wrapper")
		let name_array = rel + '[]'
		let input_field =
			'<div class="settings_each_input mb-2">' +
			'	<div class="orderhandle" rel="'+rel+'"><i class="bi bi-grip-vertical"></i></div>' +
			'	<input class="form-control" id="'+rel+'" name="'+name_array+'" value="" placeholder="Type New Data" />' +
			'	<a class="delete_setting_array" rel="'+rel+'">DELETE</a>' +
			'</div>'

		// add a new input field under corresponding parent div
		$(this).click(function () {
			parent_div.append(input_field)
			init_setting_delete() // allow deleting on newly created input field

			// remove already existing event listener on the edit button and then refresh with the newly added input field.
			let edit_button = $('.edit_setting_array[rel="'+rel+'"]')
			edit_button.off('click')
			onclick_edit(edit_button)
		})
	})
}

/**
 * DELETE A DATA AND ROW.
 * BECAUSE THE SETTINGS DATA IS AN ARRAY AT THE END, SIMPLY REMOVING THE ROW (REMOVING FROM ARRAY) WILL REMOVE THIS DATA COMPLETELY.
 */
function init_setting_delete() {
	let settings_delete_button = $('.delete_setting_array')

	settings_delete_button.each(function () {
		let direct_parent = $(this).parent()

		$(this).click(function () {
			// replace with warning and remove after
			direct_parent.html('<p class="text-danger">Click "SAVE" to update the data.</p>')
			direct_parent.delay(1000).fadeOut(500, function () {
				$(this).remove()
			})
		})
	})
}

/**
 * admin_multi_input function ... ADD
 * Copies previous row and add - this is because number of input fields per row can vary.
 */
function init_multi_input_add() {
	let multi_input__add = $('.multi_input__add')

	multi_input__add.each(function () {
		let row_name = $(this).data('name')
		let original_row = '#' + row_name	// row to copy content
		let row_wrapper = '#' + row_name + '_wrapper'  // wrapper that the content will append
		let hidden_counter_div = $('#' + $(this).attr('data-counter-id'))

		// $(this) is the "ADD" button
		$(this).click(function () {
			let count = hidden_counter_div.attr('value')

			let new_row_html = $(original_row).html()
			let new_row_name = row_name + '_' + count
			let row_to_add = '<div class="settings_multi_input mb-3" id="'+new_row_name+'">' + new_row_html + '</div>'
			$(row_wrapper).append(row_to_add)

			$('#' + new_row_name + ' input').each(function () {
				$(this).attr('value', '')
				$(this).attr('placeholder', 'Please enter a value')
			})

			// add one up the counter
			hidden_counter_div.attr('value', ++count)

			// add onclick event on the newly created delete button
			multi_input_delete($('#' + new_row_name + ' .multi_input__delete'))
		})
	})
}

/**
 * Init delete function on all multi-input delete button
 */
function init_multi_input_delete() {
	let multi_input__delete = $('.multi_input__delete')

	multi_input__delete.each(function () {
		multi_input_delete($(this))
	})
}

/**
 * Delete a single row of multi-input form
 * @param each_delete_btn
 */
function multi_input_delete(each_delete_btn) {
	let row_to_delete = each_delete_btn.parent() // row to delete is the direct parent of the delete button
	let hidden_counter_div = $('#' + each_delete_btn.attr('rel'))

	each_delete_btn.click(function() {
		let current_counter = hidden_counter_div.attr('value')
		let new_counter = current_counter - 1

		if (new_counter === 0) return	// prevent all input field from deleting

		hidden_counter_div.attr('value', new_counter)
		row_to_delete.remove()
	})
}

function init_s3_change() {
	// modal trigger
	$('#s3_folder').click(function () {
		$('#s3_change_modal').modal("show")
	})

	// remove readonly
	$('#s3_change_name_confirm').click(function () {
		let s3_name_input = $('#s3_folder')
		s3_name_input.removeAttr('readonly')
		s3_name_input.off('click')
	})
}

function update_mls_lat_long(new_position) {
	// select mls map lat long input fields
	$('#mapsearch_lat').attr('value', new_position.lat())
	$('#mapsearch_long').attr('value', new_position.lng())
}
function update_office_lat_long(new_position) {
	// select mls map lat long input fields
	$('#office_lat').attr('value', new_position.lat())
	$('#office_long').attr('value', new_position.lng())
}