<?php
/**
 * Filename: subareas_mod.php
 * Description: Edit subarea data
 *
 * Accessibility: Same as area.php
 */
include 'start.php';
redirect_invalid_user(USER_LOGIN_AGENT, true); // Agent user does not have access to this page.

global $settings;

$destinationfolder = 'subareas';
$destinationtable = 'subareas';

if ($_POST) {
    $current_mode   = $_POST['mode'];           // either `new` or `modify`.
    $idr            = $_POST['idr'] ?: false;   // could be empty if `new`.
    $allow_submit   = true;

    if ($_POST['polygon'] != '') {
        $string = str_ireplace(array('new google.maps.LatLng','),'), '', $_POST['polygon']);
        $string = preg_replace("/[^0-9\.\-\,\\n]/", "", $string);
        $_POST['polygon'] = $string;
    }

    // ON SUBMIT BEHAVIOR
    if ($allow_submit) {
        $update_id = form_to_table($destinationtable, $_POST, $idr);

        if (is_numeric($update_id)) {
            $subarea = new subarea();
            $subarea->initialize($update_id);

            // different success messages depending on "created" or "modified"
            $post_title         = $_POST['name'] ?: 'Name Needed';
            $page_id_display    = login_level_check(1) ? '(ID: '.$update_id.')' : '';
            $status             = ($current_mode == 'new' && $idr === false) ? 'added' : 'modified';
            $_SESSION['success-message'] = "<p><b>Success!</b> The area data has been $status for <span style='text-decoration: underline'>$post_title $page_id_display</span>.</p>";

            // redirect & refresh the object data.
            header('Location:'.$settings['sitepath'].ltrim($_SERVER['PHP_SELF'], '/').'?idr='.$update_id);
            exit();

        } else {
            // updated failed ... create error message.
            $error = '<p><b>Error</b> There was an error while attempting to '.($current_mode=='modify' ? 'update' : 'create').' your new listing. Error: <i>'.$update_id.'</i>. Please contact our support desk with this message.</p>';
        }
    } else {
        $error = "<p><b>Warning!</b> Invalid value passed. Please verify your input or contact Brixwork Support.</p>";
    }
}

if (!$_POST):
    // TODO: Add ?version='.$brixwork_version to js. AND minify!
    // these scripts are only need when form is being edited ... do not include when the form is being submitted
    $scriptinclude = array('areas_mod.js');
    $scriptinsert = '<script defer src="https://maps.googleapis.com/maps/api/js?key='.$settings['google_maps_api_key'].'&callback=initMap"></script>';
endif;

include 'header.php';

$preset_object_type = "subareas";                               // essential variable
include "includes/object_mod_tabs/object_mod__prep.php";        // essential file inclusion

// header_html is separated from header.php on purpose.
include 'includes/header_html.php';
?>

<form role="form" id="subareas_mod_form" class="brixwork_admin_container mod_form" method="post" enctype="multipart/form-data" action="<?=$_SERVER['PHP_SELF']."?mode=".$_GET['mode']?>">
    <h1 id="admin_mod__title">
        <?php if($_GET['mode']=='new') { echo 'Adding A New Subarea'; } else { echo 'Editing '.$subarea->name; } ?>
    </h1>

    <?php
    // SUCCESS OR ERROR MESSAGE ON FORM SUBMIT.
    session_alert_display('success-message');

    if ($error)
        echo brixwork_alert($error, 'error');
    ?>

    <div class="manage_object_tab_content tab-content">
        <div class="manage_listing_each_tab tab-pane fade show active" id="basic-info-tab" role="tabpanel" aria-labelledby="Basic-Info" tabindex="0">

            <?php // AREA DETAILS SECTION ?>
            <div id="settings_main_site" class="each_tab__category brixwork_inner_spacing w-100">
                <h3 class="each_tab__category_title">Details</h3>

                <div class="row pt-2">
                    <?php // DATA INPUT SECTIONS ?>
                    <div class="col-lg-7">
                        <div class="mb-4">
                            <?php
                            $readonly = intval($settings['mls_integrated']) == 1 && $_GET['mode'] == 'modify' ? 'readonly' : '';
                            admin_text_basic( array(
                                'name' => 'name',
                                'value' => $subarea->name,
                                'label' => 'Name of City/Area',
                                'readonly' => $readonly,
                                'placeholder' => 'Vancouver'
                            )); ?>
                        </div>

                        <div class="mb-4">
                            <?php
                            admin_textarea( array(
                                'name' => 'polygon',
                                'value' => $subarea->data['polygon'],
                                'label' => 'Custom Map Boundary Coordinates',
                                'rows' => 8,
                            )); ?>
                        </div>

                        <div class="row mb-4 mb-lg-0">
                            <div class="col-lg-7 polygon_instruction">
                                <h5>Only include the following portion</h5>
                                <p>new google.maps.LatLng(49.204364,-123.116913),</p>
                                <p>new google.maps.LatLng(49.271725,-123.114338),</p>
                                <p>new google.maps.LatLng(49.276317,-123.113995)</p>
                            </div>
                            <div class="col-lg-5 polygon_instruction">
                                <h5>Or, just the coordinates</h5>
                                <p>49.204364,-123.116913,</p>
                                <p>49.271725,-123.114338,</p>
                                <p>49.276317,-123.113995,</p>
                            </div>
                        </div>
                    </div>

                    <?php // MAP SECTION ?>
                    <div class="col-lg-5">
                        <?php // TODO: MAINTAIN POLY LINES IF COORDINATES EXIST
                        if ($subarea->lat && $subarea->long) {
                            $subarea_lat  = $subarea->lat;
                            $subarea_long = $subarea->long;
                        }
                        else {
                            $default_lat_long = explode(',', $settings['baselatlong']);
                            $subarea_lat   = $default_lat_long[0];
                            $subarea_long  = $default_lat_long[1];
                        }
                        ?>

                        <label class="control-label orange">Map for Precise Location</label>
                        <div id="areamapcontainer" class="listingmapcontainer box-shadow" data-name="<?=$subarea->name?>" data-area-name="<?=$subarea->city?>" data-lat="<?=$subarea_lat?>" data-long="<?=$subarea_long?>">
                            <div id="areamap" class="listingmap"></div>
                        </div>

                        <div class="map_functions_wrapper mt-4">
                            <button type="button" class="btn btn-admin" id="find_address_on_map">Find Address</button>
                            <button type="button" class="btn btn-admin light_blue" id="reset_map">Reset Map</button>
                        </div>

                        <input aria-label="Area Latitude to generate Map" type="hidden" name="lat" id="lat" class="form-control" value="<?=$subarea->lat?>"/>
                        <input aria-label="Area Longitude to generate Map" type="hidden" name="long" id="long" class="form-control" value="<?=$subarea->long?>"/>
                    </div>
                </div>
            </div>

            
            <?php // AREA DESCRIPTION SECTION ?>
            <div id="settings_main_site" class="each_tab__category brixwork_inner_spacing w-100">
                <h3 class="each_tab__category_title">Area Description</h3>

                <div class="row pt-2">
                    <div class="col-lg-6 mb-4 mb-lg-0">
                        <div class="bio_wrapper mb-4">
                            <?php
                            admin_textarea(array(
                                'name' => 'content',
                                'value' => cleanupfortextfield($subarea->data['content']),
                                'label' => 'Description',
                                'rows' => 8,
                                'placeholder' => 'Describe the area',
                                'class' => 'rich_editor',
                            )); ?>
                        </div>

                        <div class="excerpt_wrapper">
                            <?php
                            admin_textarea(array(
                                'name' => 'excerpt',
                                'value' => cleanupfortextfield($subarea->data['excerpt']),
                                'label' => 'Brief Excerpt',
                                'rows' => 3,
                            )); ?>
                        </div>
                    </div>

                    <div class="col-lg-6 px-5" id="">
                        <?php
                        $svg_append = 'images/admin_function_icon/';
                        echo get_svg(file_get_contents($svg_append.'brixwork_lightbulb.svg', true))
                        ?>
                        <div class="py-4">
                            <label class="control-label orange">Stock Listing Details Pages</label>
                            <p>"Description" replaces the basic coordinate display in Listings Details page, usually under "More About [neighbourhood name]".</p>
                        </div>

                        <div>
                            <label class="control-label orange">Custom Listing Details Pages</label>
                            <p>"Brief Excerpt" needs to be programmed as a section in order to display. In most cases, this can be left blank unless instructed otherwise.</p>
                        </div>
                    </div>
                </div>
            </div>

        </div>
    </div>

    <div id="submit_button_group" class="">
        <?php // HIDDEN INPUT TO BE USED IN $_POST
        if (is_object($subarea)) {
            $idr_val = $subarea->id;
            $mode_val = 'modify';
        } else {
            $idr_val = "";
            $mode_val = 'new';
        }
        echo "<input type='hidden' name='idr' id='idr' value='$idr_val' />";
        echo "<input type='hidden' name='mode' value='$mode_val' />";
        ?>
        <input type="submit" name="submitform" id="areasubmit" class="btn btn-admin" value="<?=$mode_val == 'new' ? 'Add Area' : 'Save Area'?>" />
        <a class="btn btn-admin light_blue" href="areas.php">Back</a>
    </div>
</form>


<?php
brixwork_modal_html(array(
    'header_content' => 'Subarea Name Change',
    'body_content' => "<p>You are subscribed to a MLS® Reciprocity (IDX) system. Changing the name of a city/area will cause listings from MLS® to create duplicate cities. For example, changing <u>Vancouver East</u> to <u>East Vancouver</u> will break the system as new listings from MLS&reg; will create a new city, <u>Vancouver East</u>, resulting in duplicates.</p>",
    'footer_content' => "
        <button type='button' class='btn btn-admin px-4' data-bs-dismiss='modal'>Cancel</button>
        <button type='button' class='btn btn-admin light_blue enable_edit_name px-4' data-bs-dismiss='modal'>Still Change Name</button>",
    'id' => 'change_name',
));


include 'footer.php';
?>