<?

/**
 * Ajax call to query streets from the database.
 * This accounts for different variations for street direction or suffixes, so:
 * E 39th Avenue S, East 39th Avenue S, E 39th Avenue South, East 39th Avenue South are all included
 *
 * @param string $city - the search form city to be used in the query
 * @param array $area - the search form area(s) to be used in the query
 *
 *
 * @return JSON array with the fetched streets.
 */

$seconds_to_cache = 0;
include $_SERVER['DOCUMENT_ROOT'].'/start.php';
include $_SERVER['DOCUMENT_ROOT'].'/includes/msg.inc';
include $_SERVER['DOCUMENT_ROOT'].'/includes/dropdown.inc';


if ($_POST['city']) {
	$cityId = $_POST['city'];
}

if ($_POST['area']) {
	$areasIds = implode(',', $_POST['area']);
}

// Build and prepare the query
$params_types = '';
$params_values = [];
$streetQuery = "SELECT DISTINCT street_dir, street_name, street_type, street_suffix FROM homes WHERE 1=1";

// If no filter is available then just query all streets
if (($cityId != '') || ($areasIds != '')) {
	if ($cityId != '') {
		$streetQuery .= " AND city = ?";
		$params_types .= 'i';
		$params_values[] = &$cityId;
	}
	
	if ($areasIds != '') {
		// If multiple areas
		if (strpos($areasIds,',') !== false) {
			$streetQuery .= " AND area IN (".$areasIds.")";
		} else {
			$streetQuery .= " AND area = ?";
			$params_types .= 'i';
			$params_values[] = &$areasIds;
		}
	}
}
$streetQuery .= " ORDER BY street_dir, street_name, street_type, street_suffix";


$sql = $mysqli->prepare($streetQuery);

if (($cityId != '') || ($areasIds != '')) {
	// Using this so we can call bind_param method with the right number of arguments
	call_user_func_array(array($sql, 'bind_param'), array_merge(array($params_types), $params_values));
}

$sql->execute();
$result = $sql->get_result();


if ($result->num_rows > 0) {
	$streetResult = [];
//	while($row = $result->fetch_assoc()) {
//		$streetResult[] = $row["street"];
//
//		//Add any direction/suffix variation to the array (so we have W, West, E, East...)
//		$split_street = separate_streetname($row['street']);
//		$street_name = $split_street[0];
//		$street_type = $split_street[1];
//		$street_dir = $split_street[2];
//		$street_suffix = $split_street[3];
//
//		if ($street_dir != '') {
//			$dir_array = generate_street_dir_array($street_dir);
//		}
//
//		if ($street_suffix != '') {
//			$suffix_array = generate_street_dir_array($street_suffix);
//		}
//
//		// If any direction variation is found
//		if ($dir_array != '') {
//			foreach ($dir_array as $direction) {
//				// If we also have suffixes
//				if ($suffix_array != '') {
//					foreach ($suffix_array as $suffix) {
//						$streetResult[] = ucwords(implode(' ', [$direction, $street_name, $street_type, $suffix]));
//					}
//				} else {
//					$streetResult[] = ucwords(implode(' ', [$direction, $street_name, $street_type]));
//				}
//			}
//		} else {
//			if ($suffix_array != '') {
//				foreach ($suffix_array as $suffix) {
//					$streetResult[] = ucwords(implode(' ', [$street_dir, $street_name, $street_type, $suffix]));
//				}
//			}
//		}
//	}
	
	
	while($row = $result->fetch_assoc()) {
		$street_dir = ucwords($row["street_dir"]);
		$street_name = ucwords($row["street_name"]);
		$street_type = ucwords($row["street_type"]);
		$street_suffix = ucwords($row["street_suffix"]);
		
		// Get the complete direction word (if W, then replace by West)
		if ($street_dir != '') {
			$dir_array = generate_street_dir_array($street_dir);
			rsort($dir_array); // reverse sort so the longest word (complete one) will be the first item of the array
			$street_dir = $dir_array[0];
		}
		
		if ($street_suffix != '') {
			$suffix_array = generate_street_dir_array($street_suffix);
			rsort($suffix_array);
			$street_suffix = $suffix_array[0];
		}
		
		$street = ucwords(implode(' ', array_filter([$street_dir, $street_name, $street_type, $street_suffix])));
		
		// Only insert if street has more than 4 characters, so we filter out those crippled entries
		if (strlen($street) > 4) {
			$streetResult[] = json_encode([
				'street' => $street,
				'street_dir' => $street_dir,
				'street_name' => $street_name,
				'street_type' => $street_type,
				'street_suffix' => $street_suffix
			]);
		}
	}
	
	// Remove duplicates and sort alphabetically
	$streetResult = array_unique($streetResult);
	sort($streetResult);
	
	echo json_encode($streetResult);
} else {
	echo 'Nothing found';
}

$mysqli->close();
?>