<?php
	/*
		This file generates the JS tags in the <head> section.

	    There are some rules/patterns to look for.

	    For example, Google analytics tags, adwords tags etc. need proper patterns & rules of display.

		<meta> tags, description etc. 
		<title> tag
		<og:> tags where necessary
	*/



// comprehensive Google Tag Manager for the most sophisticated ones that amalgamate into one system.
$google_tag_manager_id=false; // start with blank by default. This will return a value IF the 'google_tag_manager' field is filled.
$google_tag_manager_regex = '/GTM\-[a-zA-Z0-9]{6,}/'; // matches GTM-xxxx (new tag manager format)

// Google Analytics related, for most clients who will enter just the G-XXXXXXX (new version 4) or UA-XXXXXX (older up to version 3)
$google_analytics_id=false; // start with blank by default.
$google_analytics_regex = '/(UA|G)\-[a-zA-Z0-9-]{6,}/'; // Both UA- and G- uses the same initialization these days, no point to distinguish?

// Google Adwords tracking tag related.
$google_adwords_id = false;
$google_adwords_regex = '/AW\-[a-zA-Z0-9-]{6,}/'; // Just the UA format.


// track whether the gtag script (googletagmanager.com/gtag/js?) has already been displayed or not, so we dont show again.
$gtag_script_displayed = false;

// For tag manager syntax, see the Google Support doc here:
// https://developers.google.com/tag-manager/quickstart

preg_match($google_tag_manager_regex, $settings['google_tag_manager'], $google_tag_manager_id_matches); // get starting position.
if(is_array($google_tag_manager_id_matches) && count($google_tag_manager_id_matches)>0) {
    $google_tag_manager_id = $google_tag_manager_id_matches[0]; // should be just one match at array key 0.
}


/*
if user entered the gtm.js (tag manager) in header_js instead, we echo that out anyway later.
double entry of $settings['google_tag_manager'] ID then again on $settings['header_js'] is a user error,
we won't write a comparison or fallback/merge for that, especially because header_js can have other code
on top of just the tag manager stuff. If the user opts to put that in the header_js, they should also know to put
the tag manager trigger iframe and what not into the <body> tag.
*/

if($google_tag_manager_id!==false) {
    // Tag managers start with GTM-XXXXXXX (GTM-TR7V2MZ)
    // Extract the tag account ID ourselves... then,
    // whether the user entered the full script, or just the ID, should work universally.
    // https://developers.google.com/tag-platform/tag-manager/web shows the embed instructions.

    /*
        IMPORTANT TO NOTE
        Google Tag Manager has two parts - JS portion that shows up in <head>
        and another iFrame portion that shows up in <body>.
    */
    // We always extract just the GTM-XXX portion only from the tag manager snippet and spit out full code.
    echo '<!-- Start of Brixwork Google Tag Manager (GTM) -->' . PHP_EOL;
    ?>
    <!-- Google Tag Manager -->
    <script>(function(w,d,s,l,i){w[l]=w[l]||[];w[l].push({'gtm.start':
                new Date().getTime(),event:'gtm.js'});var f=d.getElementsByTagName(s)[0],
            j=d.createElement(s),dl=l!='dataLayer'?'&l='+l:'';j.async=true;j.src=
            'https://www.googletagmanager.com/gtm.js?id='+i+dl;f.parentNode.insertBefore(j,f);
        })(window,document,'script','dataLayer','<?=$google_tag_manager_id?>');</script>
    <!-- End Google Tag Manager -->
    <?
    echo '<!-- End of Brixwork Google Tag Manager (GTM) -->' . PHP_EOL;
}

if($settings['google_analytics']!='') {
    //
    //


    /*
     * 2020-12 upgrades to allow newer universal tags and all that.
     *
     * UA-177867262-1
     * This is the legacy tracking code format - starts with UA- (unviersal analytics, up to version 3)
     *
     * G-47894651
     * New Gtags start with G-
     *
     * But with new gtag.js code, they both work (UA or G-)
     * Note that this triggers the Analytics only.
     * Don't let the filename (gtag) confuse you with the Google Tag Manager.
     *
     * Google tag manager uses https://www.googletagmanager.com/gtm.js as the trigger, not gtag.js.
     *
     * */

    echo '<!-- Brixwork Google Analytics  -->'.PHP_EOL;

    if(preg_match($google_analytics_regex, $settings['google_analytics'])>0) {
        // Legacy tracking code starting with UA-XXX or new GA4 ones with G-XXX

        preg_match($google_analytics_regex, $settings['google_analytics'], $google_analytics_matches); // get starting position.

        $google_analytics_id = $google_analytics_matches[0]; // just fetch the first match to get the analytics ID.

        $gtag_script_displayed = true; // so we don't enable the /gtag/js again and again.
            ?>
            <!-- Entire gtag to show - both Legacy (UA-) and G4 (G-) -->
            <script async src="https://www.googletagmanager.com/gtag/js?id=<?=$google_analytics_id?>>"></script>
            <script>
                window.dataLayer = window.dataLayer || [];
                function gtag(){dataLayer.push(arguments);}
                gtag('js', new Date());

                gtag('config', '<?=$google_analytics_id?>');
            </script>

       <?php
    }
    echo '<!-- End of Brixwork Google Analytics -->'.PHP_EOL;
}

if($settings['google_adwords_tracking']!='') {
    //
    // If gtag script is enabled by analytics (most likely.. who runs ads without analytics??? we only need the push portion.


    echo '<!-- Brixwork Adwords Tracker  -->'.PHP_EOL;

    if(preg_match($google_adwords_regex, $settings['google_adwords_tracking'])>0) {
        // Legacy tracking code starting with UA-XXX or new GA4 ones with G-XXX

        preg_match($google_adwords_regex, $settings['google_adwords_tracking'], $google_adwords_matches); // get starting position.

        $google_adwords_tracking_id = $google_adwords_matches[0]; // just fetch the first match to get the analytics ID.

        if($gtag_script_displayed===false) {
        ?>
        <script async src="https://www.googletagmanager.com/gtag/js?id=<?=$google_adwords_tracking_id?>>"></script>
        <script>
            window.dataLayer = window.dataLayer || [];
            function gtag(){dataLayer.push(arguments);}
            gtag('js', new Date());

            gtag('config', '<?=$google_adwords_tracking_id?>');
        </script>

        <?
        } else {
            ?>
            <script>
                gtag('config', '<?=$google_adwords_tracking_id?>');
            </script>
            <?php
        }
    }
    echo '<!-- End of Brixwork Adwords Tracker -->'.PHP_EOL;
}



if($metatitle=='') {
    // override meta title if left blank...
    if($pagetitle!='') {
        $metatitle = strip_tags($pagetitle);
    } else {
        $metatitle = strip_tags($settings['title']);
    }
}

if($metadescription=='') {
    $metadescription = $settings['tagline'];
}

if($ogtags['title']=='') {
    $ogtags['title'] = $metatitle;
}

echo '
<title>'.strip_tags($metatitle).'</title>
<meta property="og:site_name" content="'.$settings['tagline'].' - '.$settings['title'].'"/>
<meta name="description" content="'.$metadescription.'" />
<meta property="og:type" content="website" />
';

if($ogtags['img']!='') {
    echo generate_mainimage($ogtags['img']);
}

if($ogtags['url']!='') {
    echo '<meta property="og:url" content="'.$ogtags['url'].'"/>
    <link rel="canonical" href="'.$ogtags['url'].'" />
    ';
}

if($settings['google_webmaster_tools']!='') {
    // google webmaster tools verification code, this way we avoid HTML uploads, and non-coding staff can handle!
    if(strpos(trim($settings['google_webmaster_tools']), '<meta')!==false) {
        // includes whole meta tag, so spit out the whole thing.
        echo trim($settings['google_webmaster_tools']).'
';// force a line break in code just to make view-source more berable. 
    } else {
        // it appears only the content value of the <meta> tag was entered.
        // meta tags have name, content as the key attributes.
        // only the string was entered, so generate the site verification meta tag as well!
        echo '<meta name="google-site-verification" content="'.trim(strip_tags($settings['google_webmaster_tools'])).'" />'.PHP_EOL;
    }
}



if($settings['header_js']!='') {
    /*
     * header_js can hold a lot of different things.
     * Hopefully most clients know to put in the analytics ID, adwords ID etc. above this in the regular fields that are meant for it.
     * */
    echo PHP_EOL."<!-- START of header JS included through admin -->".PHP_EOL.$settings['header_js'].PHP_EOL."<!-- END of  header JS included through admin -->".PHP_EOL;
}



if($scriptinsert_head!='') {
    /*
     * Any scripts that need to be inserted in teh <head> tag, but specific to certain pages,
     * Can be placed here.
     * For now, we tend to hard-code this in the template PHP files before
     * header.php is included (schema tag, or any page specific JS that needs to be inline, not deferred to footer)
     *
     * */
    echo PHP_EOL."<!-- START of scriptinsert_head inserted for specific pages -->".PHP_EOL.$scriptinsert_head.PHP_EOL."<!-- END of  scriptinsert_head -->".PHP_EOL;

}


// declare easy to use variables to use througout javascript calls where necessary.
include $_SERVER['DOCUMENT_ROOT']."/includes/header_tags_script.php";


?>