<?php
/*
This file determines the listing query for listing.php, and processes all the data necessary to figure out what listings to show, what page data to show and how to show it.
The default values ca be set as per the below variables in the listings.php or properties.php, otherwise the following variables apply.
*/

// first process the filename that is runnign this. Default is listings.php
if($listingsfilename=='') {
	$listingsfilename = str_ireplace('.php','', $filename);

	if($listingsfilename=='') {
		$listingsfilename = 'listings';
	}
}

if(!isset($listing_custom_filename) || $listing_custom_filename=='') {
	$listing_custom_filename = $listingsfilename;
}

$objecttype = 'home'; // define that object time called are homes (listings).

$params =  parse_pagevars($listingsfilename); // parses URL variables to $param. Not filtered to $query yet.

global $params;
if(DEBUG===true) {
	echo 'RAW PARAMS:<br />';
	if(is_countable($params) && count($params)>0) {
		foreach($params as $pkey=>$pvar) {
			echo '<strong>['.$pkey.']</strong> = '.$pvar.'<br />'.PHP_EOL;
		}
	} else {
		echo "No params were set past ".$filename."<br />".PHP_EOL;
	}

	if(is_array($params)) {
		reset($params);
	}
}


if(!isset($defaultpageid) && $params['pageid']=='') {
	// page id has not been set, and there's no default page id for listings page either, so we need to get it.
	// It's recommended to NOT fall back to this, this is one more MySQL query that is NOT necessary.
	$pagesquery = "SELECT `id` FROM `pages` where `custom_pageurl`='".$mysqli->real_escape_string($listingsfilename)."'";
	$pagesresult = $mysqli->query( $pagesquery);
	$pagesresult->data_seek(0);
	$pagerow = $pagesresult->fetch_row();
	$defaultpageid = $pagerow[0];
}

if(!isset($defaultperpage)) {
	$defaultperpage = 10; // default # of listings per page. Call $defaultperpage under listings.php to set it otherwise.
}

if(!isset($ownlistingperpage)) {
	$ownlistingperpage = $defaultperpage; // default # of pages IF displaying one's own listings or sold listings etc. where we want it all grouped. . Call $ownlistingperpage under listings.php to set it otherwise, defaults to the same as $defaultperpage
}

if(!isset($defaultquery)) {
	$defaultquery = array(
		'ownlisting'=>1,
		'sold' => array(0, 1, 2)
	); // Default $query, pulled in when it's just .com/listings/
}

if(!isset($defaultorderby)) {
	$defaultorderby = array(
		'source',
		'ord',
		'create_date'
	); // Default $defaultorderby, used when it's just .com/listings/
}

if(!isset($defaultorderdirection)) {
	$defaultorderdirection = array(
		'ASC',
		'ASC',
		'DESC'
	); // Default $defaultorderby, used when it's just .com/listings/
}

if(!isset($searchfilter)) {
	$searchfilter = array(
	); // Default $searchfilter, in 99% of cases it will filter for homes that are set to sold=0 to show active listings during MLS searches. This can include cities etc.
}

if(!isset($searchorderby)) {
	$searchorderby = array(
		'ord',
		'create_date'
	); // Default $searchorderby, used for MLS search results as default if not set.
}

if(!isset($searchorderdirection)) {
	$searchorderdirection = array(
		'ASC',
		'DESC'
	); // Default $searchorderdirection, used for MLS search results as default if not set.
}

if(!isset($blanketfilter)) {
	$blanketfilter = array(
		'publish'=>1
	); // Default $blanketfilter, in 99% of cases it will filter for homes that are set to PUBLISH, naturally.
}

if(isset($params['oldhome']) && $params['oldhome']!='') {
	$oldhomeid = remove_all_but_numbers(trim($params['oldhome']));
	$oldhome = new home;
	$oldhome->initialize($oldhomeid);
	// for recently removed MLS listings, we can show "Sorry, xxx Main street (MLS #: XXXX) is no longer available, but here are similar listings."
}

$perpage = $defaultperpage;

/* DEFAULTS SET UP COMPLETE! */


// first, funnel the URL params such as /city-Vancouver+West/min_price-1200000 etc. into $query from $param!
$query = param_to_query($params); // filter which of the $params work as listing $query vars.
// If $params was blank, $query will be just FALSE (bool)

if($query!==false) {
	// some sort of search has been done, so the ORDER BYs should no longer be the defaults "ord"  - use the search order, which is most likely date first, as the default. .
	$defaultorderby = $searchorderby;
	$defaultorderdirection = $searchorderdirection;
}

// other important search parameters such as order by, page num etc. that are OUTSIDE of the $query filters.
if(is_array($params) && array_key_exists('order_by', $params) && $params['order_by']!='') {
	$order_by = $params['order_by'];
} else {
	$order_by = $defaultorderby;
}
if(is_array($params) && array_key_exists('order_direction', $params) && $params['order_direction']!='') {
	$order_direction = $params['order_direction'];
} else {
	$order_direction = $defaultorderdirection;
}

if(is_array($params) && array_key_exists('page', $params) && $params['page']!='') {
	$page = $params['page'];
} else {
	$page = 1;
}

if(array_key_exists('listings_display_page_num', $settings) && $settings['listings_display_page_num']!='') {
	$display_page_num = $settings['listings_display_page_num'];
} else {
	$display_page_num = 30;
}

if(array_key_exists('listings_display_page_nextprev', $settings) && $settings['listings_display_page_nextprev']!='') {
	$display_page_nextprev = $settings['listings_display_page_nextprev'];
} else {
	$display_page_nextprev = false;
}

if(!is_array($query) || (is_array($query) && count($query)==0)) {
	// $query is blank, so fall back to default, featured listings of all sold statuses.
		$query = $defaultquery;
		$perpage = $ownlistingperpage;
	} else if(array_key_exists('sold', $query) && array_key_exists('pageid', $params)) {
	// sold listings, which means agent's own listings. Get own listing page limits, and do not use default filters etc.
		$perpage = $ownlistingperpage;

	} else if(array_key_exists('office_listings', $query) || array_key_exists('feature', $query) || array_key_exists('ownlisting', $query)) {
	// office listings, so ignore the city parameter etc.

	} else if(array_key_exists('bldg', $query)) {
	// building query.. show ALL listings, order of OWN listings then recent first.
		$perpage = 1000;
		$objecttype = 'building';
	} else {// queries given, so process otherwise.
		$cookie_params = array_merge($query, $params);
		if(isset($visitor) && is_object($visitor)) {
			$visitor-> search_action($_SERVER['REQUEST_URI'], $cookie_params);
		}
		// if city is not set, force to whatever $searchfilter limits to. Useful for most realtors who want van/westvan/northvan but not pitt meadows, surrey etc.
		if(!array_key_exists('city', $query) && array_key_exists('city', $searchfilter)) {
		$query['city'] = $params['city'] = $searchfilter['city'];
	}

	// if area is not set, force to whatever $searchfilter limits to. Useful for niche websites for pemberton heights etc.
	if(!array_key_exists('area', $query) && array_key_exists('area', $searchfilter)) {
		$query['area'] = $params['area'] =  $searchfilter['area'];
	}

	// if type is not set, force to whatever $searchfilter limits to. Useful for Lots/condos only websites etc.
	if(!array_key_exists('type', $query) && array_key_exists('type', $searchfilter)) {
		$query['type'] = $params['type'] = $searchfilter['type'];
	}

	// if source is set specifically (most likely =1.. because this part only handles mls searches
	if(!array_key_exists('source', $query) && array_key_exists('source', $searchfilter)) {
		$query['source'] = $searchfilter['source'];
	}

	if(!array_key_exists('sold',$params) && !array_key_exists('mylisting',$params) && !array_key_exists('ownlisting',$params)) {
		$query['sold']=array(0);
	}
}
//
//if(!is_array($query['sold']) && isset($query['sold'])) {
//	// single var, force to array.
//	$oldsold = $query['sold'];
//	unset($query['sold']);
//	$query['sold'] = array(
//		$oldsold
//	);
//}
$query = array_merge($query, $blanketfilter); // put teh final blanket filter that should go on ALL websites.. mainly publish=1
// final query var generated.

$pagelinkshtml = generate_pagelinks('', $query, $order_by, $order_direction, $perpage, $page, $display_page_num, $display_page_nextprev, $params, $listing_custom_filename, 'listings');
?>