<?
/**
 * Creates a carousel containing the listings passed in $listings_ids.
 *
 * @param array $listings_ids - array of home IDs to be displayed in the carousel
 * @param int $number_of_listings - number of listings to be displayed at the carousel
 * @param int $listings_on_mobile - number of listings to be displayed on mobile (equal or less than $number_of_listings)
 * @param array $class - any custom class to be added on the top containing div. You can use this to restyle the default look
 *
 * @return string - the html block
 */
function create_listings_carousel_yt2($listings_ids = [], $number_of_listings = 10, $carousel_id, $listings_on_mobile = 3, $class = []) {
	if (is_array($class)) {
		$class = implode(' ', $class);
	}

	if (count($listings_ids) > 0) {
		$has_cookies = false;
		$listings_viewed_array = [];
		$listings_fav_array = [];
		$favorited = false;
		$viewed = false;

		global $visitor;
		$listings_array = $visitor->get_listing_history();

		if (count($listings_array) > 0) {
			// If we have a listing_array it means we're being able to set cookies
			$has_cookies = true;

			$listings_viewed_array = array_filter($listings_array, function ($listing) {
				return $listing['action'] == 'view';
			});
			$listings_viewed_array = array_map(function ($listing) {
				return $listing['pid'];
			}, $listings_viewed_array);

			$listings_fav_array = array_filter($listings_array, function ($listing) {
				return $listing['action'] == 'favorite';
			});
			$listings_fav_array = array_map(function ($listing) {
				return $listing['pid'];
			}, $listings_fav_array);
		}

		$carousel_query['id'] = $listings_ids;
		$carousel_query['publish'] = 1;
		// Better to run one query and get all the homes data needed than instantiate home by home and run multiple queries individually
		$carousel_listings = get_properties('', $carousel_query, '', '', $number_of_listings, 1, false, true);

		$k = 0;
		$listings_block = '';
		$listings_block_mobile = '';
		foreach ($carousel_listings as $listing) {
			$home = new home;
			$home->initialize($listing['id'], $listing);

			if ($has_cookies) {
				$favorited = in_array($home->id, $listings_fav_array);
				$viewed = in_array($home->id, $listings_viewed_array);
			}

			$block = '';
			$active = $k === 0 ? ' active' : '';

			$listings_block .= "<div class='col-lg-6 col-xxl-4 col-xxxxl-3 carousel-item$active$next'>";

			$block .= carousel_listing_display_yt2($home, $favorited, $viewed, $k);
			$listings_block .= $block;


			$listings_block .= "</div>";
			$k++;

			if ($k <= $listings_on_mobile || count($carousel_listings) < 5) {
				$listings_block_mobile .= '<div class="item-mobile">';
				$listings_block_mobile .= $block;
				$listings_block_mobile .= '</div>';
			}
		}


		/*******
		 * THE RETURN
		 *******/

		$return = '<div class="carousel_fav_n_recent container-full">
                <div id="' . $carousel_id . '" class="carousel custom_carousel slide d-none ' . $class . (count($carousel_listings) < 5 ? ' ' : ' d-md-block ') . '" data-ride="carousel">
                    <div class="carousel-inner row w-100 mx-auto" role="listbox">
                        ' . $listings_block . '
                    </div>
                    <!-- Controls -->
                    <a class="left carousel-control-prev" href="#' . $carousel_id . '" data-slide="prev">
                        <span class="carousel-control-prev-icon" aria-hidden="true"></span>
                        <span class="sr-only">Previous</span>
                    </a>
                    <a class="right carousel-control-next" href="#' . $carousel_id . '" data-slide="next">
                        <span class="carousel-control-next-icon" aria-hidden="true"></span>
                        <span class="sr-only">Next</span>
                    </a>
                </div>
                <div class="' . (count($carousel_listings) < 5 ? '' : ' d-md-none ') . ' mobile_bs_carousel ' . $class . '">
                    ' . $listings_block_mobile . '
                </div>
            </div>';

		return $return;
	}

	return '';
}


/**
 * Creates the individual listing container to be displayed within the listings carousel.
 *
 * @param home $home - the home object already instantiated
 * @param bool $favorited - has the user favorited this listing?
 * @param bool $viewed - has the user viewed this listing before?
 *
 * @return string - the html block
 */
function carousel_listing_display_yt2(home $home, $favorited = false, $viewed = false, $count = null) {
	global $settings;

	// GET PHOTO
	$photo_path = $home->get_main_images_path(0, 'noimage.jpg', 0);
	$photo = "<img loading='lazy' class='d-block' src='$photo_path' title='$home->fulladdress photo $count' alt='$home->fulladdress photo $count' />";


	// GET ADDRESS
	$address1 = $home->address;
	$address2 = $home->areacity;


	// GET BBS
	// Bed, bath & sqft
	$bbs = '';
	if (($home->bedroom != '') || ($home->bathroom != '') || ($home->sqft != '')) {
		$bbs = '
            <p class="bbs_wrapper">' .
			implode(', ', array($home->bedroom.($home->bedroom > 1 ? ' Beds' : ' Bed'), $home->bathroom.($home->bathroom > 1 ? ' Baths' : ' Bath'), $home->sqft.(strpos($home->sqft, 'sqft') ? '' : 'sqft'))).
			'</p>
        ';
	}


	// GET VISITOR LISTING INFO
	// Preload all the SVGs to be used on this page
	// If you need to insert icons with custom classes, just insert it on the get_svg() as the last param.
	// if you need to change the svg, note that the SVGs are in the templates/main/images/ so you can change it site to site.
	// The default icons will be packaged with the YT2 install of course.
	$fav_viewed_svgs = array(
		'listing_carousel_favorite_icon' => get_svg(file_get_contents($settings['includepath'] . 'images/icons/listing_carousel_favorite_icon.svg')),
		'listing_carousel_viewed_icon'   => get_svg(file_get_contents($settings['includepath'] . 'images/icons/listing_carousel_viewed_icon.svg')),
	);

	if ($favorited) {
		$fav_viewed_icon = '<span class="fav_viewed_icon">' . $fav_viewed_svgs['listing_carousel_favorite_icon'] . '</span>';
	} else if ($viewed) {
		$fav_viewed_icon = '<span class="fav_viewed_icon">' . $fav_viewed_svgs['listing_carousel_viewed_icon'] . '</span>';
	} else {
		$fav_viewed_icon = '';
	}


	/*******
	 * THE RETURN
	 *******/

	$display_price = yt2_get_price_data($home);

	$fav_rec_option = $site_options_array['fav_rec_gallery_option'] !== null ? $site_options_array['fav_rec_gallery_option'] : 1;

	$overlay = $fav_rec_option == 1 ? '<div class="overlay"></div>' : '';

	$return = '
        <a class="fav_listing_card" href="' . $home->get_property_link($settings['url_trail'], 'showlisting/') . '" title="View ' . $home->fulladdress . '">
            <div class="listing_photo">
                <div class="photo_wrapper">
                    ' . $fav_viewed_icon . '
                    ' . $photo . '
                </div>
            </div>
            <div class="details_wrapper">
                '.$overlay.'
                <div class="address_wrapper">
                    <p class="dark_text h5_style address1">' . $address1 . '</p>
                    <p class="dark_text address2">' . $address2 . '</p>
                </div>
                <p class="light_text price">' . $display_price . '</p>
                '.$bbs.'
            </div>
        </a>
        ';

	return $return;
}
